# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/cluster.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\014ClusterProto'),
  serialized_pb=_b('\n\x1eprotobuf/cluster/cluster.proto\x12\x16grakn.protocol.cluster\"<\n\x07\x43luster\x1a\x31\n\x07Servers\x1a\x05\n\x03Req\x1a\x1f\n\x03Res\x12\x18\n\x07servers\x18\x01 \x03(\tR\x07serversB&\n\x16grakn.protocol.clusterB\x0c\x43lusterProtob\x06proto3')
)




_CLUSTER_SERVERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Cluster.Servers.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=85,
)

_CLUSTER_SERVERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Cluster.Servers.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='grakn.protocol.cluster.Cluster.Servers.Res.servers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=118,
)

_CLUSTER_SERVERS = _descriptor.Descriptor(
  name='Servers',
  full_name='grakn.protocol.cluster.Cluster.Servers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_SERVERS_REQ, _CLUSTER_SERVERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=118,
)

_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='grakn.protocol.cluster.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_SERVERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=118,
)

_CLUSTER_SERVERS_REQ.containing_type = _CLUSTER_SERVERS
_CLUSTER_SERVERS_RES.containing_type = _CLUSTER_SERVERS
_CLUSTER_SERVERS.containing_type = _CLUSTER
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), dict(

  Servers = _reflection.GeneratedProtocolMessageType('Servers', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CLUSTER_SERVERS_REQ,
      __module__ = 'protobuf.cluster.cluster_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CLUSTER_SERVERS_RES,
      __module__ = 'protobuf.cluster.cluster_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers.Res)
      ))
    ,
    DESCRIPTOR = _CLUSTER_SERVERS,
    __module__ = 'protobuf.cluster.cluster_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers)
    ))
  ,
  DESCRIPTOR = _CLUSTER,
  __module__ = 'protobuf.cluster.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster)
  ))
_sym_db.RegisterMessage(Cluster)
_sym_db.RegisterMessage(Cluster.Servers)
_sym_db.RegisterMessage(Cluster.Servers.Req)
_sym_db.RegisterMessage(Cluster.Servers.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
