# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import concept_pb2 as protobuf_dot_concept__pb2
from grakn_protocol.protobuf import logic_pb2 as protobuf_dot_logic__pb2
from grakn_protocol.protobuf import options_pb2 as protobuf_dot_options__pb2
from grakn_protocol.protobuf import query_pb2 as protobuf_dot_query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/transaction.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\020TransactionProto'),
  serialized_pb=_b('\n\x1aprotobuf/transaction.proto\x12\x0egrakn.protocol\x1a\x16protobuf/concept.proto\x1a\x14protobuf/logic.proto\x1a\x16protobuf/options.proto\x1a\x14protobuf/query.proto\"\xb7\x0e\n\x0bTransaction\x1a\xcc\x06\n\x03Req\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12I\n\x08metadata\x18\x02 \x03(\x0b\x32-.grakn.protocol.Transaction.Req.MetadataEntryR\x08metadata\x12%\n\x0elatency_millis\x18\x03 \x01(\x05R\rlatencyMillis\x12\x1c\n\x08\x63ontinue\x18\x04 \x01(\x08H\x00R\x08\x63ontinue\x12\x41\n\x08open_req\x18\x05 \x01(\x0b\x32$.grakn.protocol.Transaction.Open.ReqH\x00R\x07openReq\x12G\n\ncommit_req\x18\x06 \x01(\x0b\x32&.grakn.protocol.Transaction.Commit.ReqH\x00R\tcommitReq\x12M\n\x0crollback_req\x18\x07 \x01(\x0b\x32(.grakn.protocol.Transaction.Rollback.ReqH\x00R\x0brollbackReq\x12\x38\n\tquery_req\x18\x08 \x01(\x0b\x32\x19.grakn.protocol.Query.ReqH\x00R\x08queryReq\x12T\n\x13\x63oncept_manager_req\x18\t \x01(\x0b\x32\".grakn.protocol.ConceptManager.ReqH\x00R\x11\x63onceptManagerReq\x12\x38\n\tthing_req\x18\n \x01(\x0b\x32\x19.grakn.protocol.Thing.ReqH\x00R\x08thingReq\x12\x35\n\x08type_req\x18\x0b \x01(\x0b\x32\x18.grakn.protocol.Type.ReqH\x00R\x07typeReq\x12N\n\x11logic_manager_req\x18\x0c \x01(\x0b\x32 .grakn.protocol.LogicManager.ReqH\x00R\x0flogicManagerReq\x12\x35\n\x08rule_req\x18\r \x01(\x0b\x32\x18.grakn.protocol.Rule.ReqH\x00R\x07ruleReq\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x05\n\x03req\x1a\xb3\x05\n\x03Res\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x04\x64one\x18\x02 \x01(\x08H\x00R\x04\x64one\x12\x1c\n\x08\x63ontinue\x18\x04 \x01(\x08H\x00R\x08\x63ontinue\x12\x41\n\x08open_res\x18\x05 \x01(\x0b\x32$.grakn.protocol.Transaction.Open.ResH\x00R\x07openRes\x12G\n\ncommit_res\x18\x06 \x01(\x0b\x32&.grakn.protocol.Transaction.Commit.ResH\x00R\tcommitRes\x12M\n\x0crollback_res\x18\x07 \x01(\x0b\x32(.grakn.protocol.Transaction.Rollback.ResH\x00R\x0brollbackRes\x12\x38\n\tquery_res\x18\x08 \x01(\x0b\x32\x19.grakn.protocol.Query.ResH\x00R\x08queryRes\x12T\n\x13\x63oncept_manager_res\x18\t \x01(\x0b\x32\".grakn.protocol.ConceptManager.ResH\x00R\x11\x63onceptManagerRes\x12\x38\n\tthing_res\x18\n \x01(\x0b\x32\x19.grakn.protocol.Thing.ResH\x00R\x08thingRes\x12\x35\n\x08type_res\x18\x0b \x01(\x0b\x32\x18.grakn.protocol.Type.ResH\x00R\x07typeRes\x12N\n\x11logic_manager_res\x18\x0c \x01(\x0b\x32 .grakn.protocol.LogicManager.ResH\x00R\x0flogicManagerRes\x12\x35\n\x08rule_res\x18\r \x01(\x0b\x32\x18.grakn.protocol.Rule.ResH\x00R\x07ruleResB\x05\n\x03res\x1a\xd3\x01\n\x04Open\x1a\x8d\x01\n\x03Req\x12\x1d\n\nsession_id\x18\x01 \x01(\x0cR\tsessionId\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32 .grakn.protocol.Transaction.TypeR\x04type\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32\x17.grakn.protocol.OptionsR\x07options\x1a;\n\x03Res\x12\x34\n\x16processing_time_millis\x18\x01 \x01(\x05R\x14processingTimeMillis\x1a\x16\n\x06\x43ommit\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a\x18\n\x08Rollback\x1a\x05\n\x03Req\x1a\x05\n\x03Res\"\x1b\n\x04Type\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01\x42\"\n\x0egrakn.protocolB\x10TransactionProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_concept__pb2.DESCRIPTOR,protobuf_dot_logic__pb2.DESCRIPTOR,protobuf_dot_options__pb2.DESCRIPTOR,protobuf_dot_query__pb2.DESCRIPTOR,])



_TRANSACTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='grakn.protocol.Transaction.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='READ', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1959,
  serialized_end=1986,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTION_TYPE)


_TRANSACTION_REQ_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='grakn.protocol.Transaction.Req.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grakn.protocol.Transaction.Req.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.Transaction.Req.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=992,
)

_TRANSACTION_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grakn.protocol.Transaction.Req.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grakn.protocol.Transaction.Req.metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_millis', full_name='grakn.protocol.Transaction.Req.latency_millis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='latencyMillis', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continue', full_name='grakn.protocol.Transaction.Req.continue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_req', full_name='grakn.protocol.Transaction.Req.open_req', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_req', full_name='grakn.protocol.Transaction.Req.commit_req', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_req', full_name='grakn.protocol.Transaction.Req.rollback_req', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rollbackReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_req', full_name='grakn.protocol.Transaction.Req.query_req', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_manager_req', full_name='grakn.protocol.Transaction.Req.concept_manager_req', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='conceptManagerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_req', full_name='grakn.protocol.Transaction.Req.thing_req', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_req', full_name='grakn.protocol.Transaction.Req.type_req', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logic_manager_req', full_name='grakn.protocol.Transaction.Req.logic_manager_req', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logicManagerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_req', full_name='grakn.protocol.Transaction.Req.rule_req', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_REQ_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Transaction.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=155,
  serialized_end=999,
)

_TRANSACTION_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grakn.protocol.Transaction.Res.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='done', full_name='grakn.protocol.Transaction.Res.done', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='done', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continue', full_name='grakn.protocol.Transaction.Res.continue', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_res', full_name='grakn.protocol.Transaction.Res.open_res', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_res', full_name='grakn.protocol.Transaction.Res.commit_res', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_res', full_name='grakn.protocol.Transaction.Res.rollback_res', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rollbackRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_res', full_name='grakn.protocol.Transaction.Res.query_res', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_manager_res', full_name='grakn.protocol.Transaction.Res.concept_manager_res', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='conceptManagerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_res', full_name='grakn.protocol.Transaction.Res.thing_res', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_res', full_name='grakn.protocol.Transaction.Res.type_res', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logic_manager_res', full_name='grakn.protocol.Transaction.Res.logic_manager_res', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logicManagerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_res', full_name='grakn.protocol.Transaction.Res.rule_res', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Transaction.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1002,
  serialized_end=1693,
)

_TRANSACTION_OPEN_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Open.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='grakn.protocol.Transaction.Open.Req.session_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Transaction.Open.Req.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='grakn.protocol.Transaction.Open.Req.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1846,
)

_TRANSACTION_OPEN_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Open.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_time_millis', full_name='grakn.protocol.Transaction.Open.Res.processing_time_millis', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='processingTimeMillis', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1907,
)

_TRANSACTION_OPEN = _descriptor.Descriptor(
  name='Open',
  full_name='grakn.protocol.Transaction.Open',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_OPEN_REQ, _TRANSACTION_OPEN_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1696,
  serialized_end=1907,
)

_TRANSACTION_COMMIT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Commit.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=160,
)

_TRANSACTION_COMMIT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Commit.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1007,
)

_TRANSACTION_COMMIT = _descriptor.Descriptor(
  name='Commit',
  full_name='grakn.protocol.Transaction.Commit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_COMMIT_REQ, _TRANSACTION_COMMIT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=1931,
)

_TRANSACTION_ROLLBACK_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Rollback.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=160,
)

_TRANSACTION_ROLLBACK_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Rollback.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1007,
)

_TRANSACTION_ROLLBACK = _descriptor.Descriptor(
  name='Rollback',
  full_name='grakn.protocol.Transaction.Rollback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_ROLLBACK_REQ, _TRANSACTION_ROLLBACK_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1933,
  serialized_end=1957,
)

_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='grakn.protocol.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_REQ, _TRANSACTION_RES, _TRANSACTION_OPEN, _TRANSACTION_COMMIT, _TRANSACTION_ROLLBACK, ],
  enum_types=[
    _TRANSACTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=1986,
)

_TRANSACTION_REQ_METADATAENTRY.containing_type = _TRANSACTION_REQ
_TRANSACTION_REQ.fields_by_name['metadata'].message_type = _TRANSACTION_REQ_METADATAENTRY
_TRANSACTION_REQ.fields_by_name['open_req'].message_type = _TRANSACTION_OPEN_REQ
_TRANSACTION_REQ.fields_by_name['commit_req'].message_type = _TRANSACTION_COMMIT_REQ
_TRANSACTION_REQ.fields_by_name['rollback_req'].message_type = _TRANSACTION_ROLLBACK_REQ
_TRANSACTION_REQ.fields_by_name['query_req'].message_type = protobuf_dot_query__pb2._QUERY_REQ
_TRANSACTION_REQ.fields_by_name['concept_manager_req'].message_type = protobuf_dot_concept__pb2._CONCEPTMANAGER_REQ
_TRANSACTION_REQ.fields_by_name['thing_req'].message_type = protobuf_dot_concept__pb2._THING_REQ
_TRANSACTION_REQ.fields_by_name['type_req'].message_type = protobuf_dot_concept__pb2._TYPE_REQ
_TRANSACTION_REQ.fields_by_name['logic_manager_req'].message_type = protobuf_dot_logic__pb2._LOGICMANAGER_REQ
_TRANSACTION_REQ.fields_by_name['rule_req'].message_type = protobuf_dot_logic__pb2._RULE_REQ
_TRANSACTION_REQ.containing_type = _TRANSACTION
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['continue'])
_TRANSACTION_REQ.fields_by_name['continue'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['open_req'])
_TRANSACTION_REQ.fields_by_name['open_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['commit_req'])
_TRANSACTION_REQ.fields_by_name['commit_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['rollback_req'])
_TRANSACTION_REQ.fields_by_name['rollback_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['query_req'])
_TRANSACTION_REQ.fields_by_name['query_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['concept_manager_req'])
_TRANSACTION_REQ.fields_by_name['concept_manager_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['thing_req'])
_TRANSACTION_REQ.fields_by_name['thing_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['type_req'])
_TRANSACTION_REQ.fields_by_name['type_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['logic_manager_req'])
_TRANSACTION_REQ.fields_by_name['logic_manager_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['rule_req'])
_TRANSACTION_REQ.fields_by_name['rule_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_RES.fields_by_name['open_res'].message_type = _TRANSACTION_OPEN_RES
_TRANSACTION_RES.fields_by_name['commit_res'].message_type = _TRANSACTION_COMMIT_RES
_TRANSACTION_RES.fields_by_name['rollback_res'].message_type = _TRANSACTION_ROLLBACK_RES
_TRANSACTION_RES.fields_by_name['query_res'].message_type = protobuf_dot_query__pb2._QUERY_RES
_TRANSACTION_RES.fields_by_name['concept_manager_res'].message_type = protobuf_dot_concept__pb2._CONCEPTMANAGER_RES
_TRANSACTION_RES.fields_by_name['thing_res'].message_type = protobuf_dot_concept__pb2._THING_RES
_TRANSACTION_RES.fields_by_name['type_res'].message_type = protobuf_dot_concept__pb2._TYPE_RES
_TRANSACTION_RES.fields_by_name['logic_manager_res'].message_type = protobuf_dot_logic__pb2._LOGICMANAGER_RES
_TRANSACTION_RES.fields_by_name['rule_res'].message_type = protobuf_dot_logic__pb2._RULE_RES
_TRANSACTION_RES.containing_type = _TRANSACTION
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['done'])
_TRANSACTION_RES.fields_by_name['done'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['continue'])
_TRANSACTION_RES.fields_by_name['continue'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['open_res'])
_TRANSACTION_RES.fields_by_name['open_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['commit_res'])
_TRANSACTION_RES.fields_by_name['commit_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['rollback_res'])
_TRANSACTION_RES.fields_by_name['rollback_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['query_res'])
_TRANSACTION_RES.fields_by_name['query_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['concept_manager_res'])
_TRANSACTION_RES.fields_by_name['concept_manager_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['thing_res'])
_TRANSACTION_RES.fields_by_name['thing_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['type_res'])
_TRANSACTION_RES.fields_by_name['type_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['logic_manager_res'])
_TRANSACTION_RES.fields_by_name['logic_manager_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['rule_res'])
_TRANSACTION_RES.fields_by_name['rule_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_OPEN_REQ.fields_by_name['type'].enum_type = _TRANSACTION_TYPE
_TRANSACTION_OPEN_REQ.fields_by_name['options'].message_type = protobuf_dot_options__pb2._OPTIONS
_TRANSACTION_OPEN_REQ.containing_type = _TRANSACTION_OPEN
_TRANSACTION_OPEN_RES.containing_type = _TRANSACTION_OPEN
_TRANSACTION_OPEN.containing_type = _TRANSACTION
_TRANSACTION_COMMIT_REQ.containing_type = _TRANSACTION_COMMIT
_TRANSACTION_COMMIT_RES.containing_type = _TRANSACTION_COMMIT
_TRANSACTION_COMMIT.containing_type = _TRANSACTION
_TRANSACTION_ROLLBACK_REQ.containing_type = _TRANSACTION_ROLLBACK
_TRANSACTION_ROLLBACK_RES.containing_type = _TRANSACTION_ROLLBACK
_TRANSACTION_ROLLBACK.containing_type = _TRANSACTION
_TRANSACTION_TYPE.containing_type = _TRANSACTION
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(

    MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_REQ_METADATAENTRY,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Req.MetadataEntry)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_REQ,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _TRANSACTION_RES,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Res)
    ))
  ,

  Open = _reflection.GeneratedProtocolMessageType('Open', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_OPEN_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_OPEN_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_OPEN,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open)
    ))
  ,

  Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_COMMIT_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_COMMIT_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_COMMIT,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit)
    ))
  ,

  Rollback = _reflection.GeneratedProtocolMessageType('Rollback', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_ROLLBACK_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_ROLLBACK_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_ROLLBACK,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback)
    ))
  ,
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'protobuf.transaction_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)
_sym_db.RegisterMessage(Transaction.Req)
_sym_db.RegisterMessage(Transaction.Req.MetadataEntry)
_sym_db.RegisterMessage(Transaction.Res)
_sym_db.RegisterMessage(Transaction.Open)
_sym_db.RegisterMessage(Transaction.Open.Req)
_sym_db.RegisterMessage(Transaction.Open.Res)
_sym_db.RegisterMessage(Transaction.Commit)
_sym_db.RegisterMessage(Transaction.Commit.Req)
_sym_db.RegisterMessage(Transaction.Commit.Res)
_sym_db.RegisterMessage(Transaction.Rollback)
_sym_db.RegisterMessage(Transaction.Rollback.Req)
_sym_db.RegisterMessage(Transaction.Rollback.Res)


DESCRIPTOR._options = None
_TRANSACTION_REQ_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)
