# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/grakn_cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf.cluster import cluster_pb2 as protobuf_dot_cluster_dot_cluster__pb2
from grakn_protocol.protobuf.cluster import database_pb2 as protobuf_dot_cluster_dot_database__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/grakn_cluster.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\021GraknClusterProto'),
  serialized_pb=_b('\n$protobuf/cluster/grakn_cluster.proto\x12\x16grakn.protocol.cluster\x1a\x1eprotobuf/cluster/cluster.proto\x1a\x1fprotobuf/cluster/database.proto2\xc3\x02\n\x0cGraknCluster\x12k\n\x0f\x63luster_servers\x12+.grakn.protocol.cluster.Cluster.Servers.Req\x1a+.grakn.protocol.cluster.Cluster.Servers.Res\x12\x62\n\x0c\x64\x61tabase_get\x12(.grakn.protocol.cluster.Database.Get.Req\x1a(.grakn.protocol.cluster.Database.Get.Res\x12\x62\n\x0c\x64\x61tabase_all\x12(.grakn.protocol.cluster.Database.All.Req\x1a(.grakn.protocol.cluster.Database.All.ResB+\n\x16grakn.protocol.clusterB\x11GraknClusterProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_cluster_dot_cluster__pb2.DESCRIPTOR,protobuf_dot_cluster_dot_database__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_GRAKNCLUSTER = _descriptor.ServiceDescriptor(
  name='GraknCluster',
  full_name='grakn.protocol.cluster.GraknCluster',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=130,
  serialized_end=453,
  methods=[
  _descriptor.MethodDescriptor(
    name='cluster_servers',
    full_name='grakn.protocol.cluster.GraknCluster.cluster_servers',
    index=0,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_cluster__pb2._CLUSTER_SERVERS_REQ,
    output_type=protobuf_dot_cluster_dot_cluster__pb2._CLUSTER_SERVERS_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_get',
    full_name='grakn.protocol.cluster.GraknCluster.database_get',
    index=1,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_GET_REQ,
    output_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_GET_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_all',
    full_name='grakn.protocol.cluster.GraknCluster.database_all',
    index=2,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_ALL_REQ,
    output_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_ALL_RES,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRAKNCLUSTER)

DESCRIPTOR.services_by_name['GraknCluster'] = _GRAKNCLUSTER

# @@protoc_insertion_point(module_scope)
