# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/query.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import answer_pb2 as protobuf_dot_answer__pb2
from grakn_protocol.protobuf import options_pb2 as protobuf_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/query.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\nQueryProto'),
  serialized_pb=_b('\n\x14protobuf/query.proto\x12\x0egrakn.protocol\x1a\x15protobuf/answer.proto\x1a\x16protobuf/options.proto\"\xb0\x11\n\x05Query\x1a\xec\x05\n\x03Req\x12\x31\n\x07options\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.OptionsR\x07options\x12\x41\n\ndefine_req\x18\x64 \x01(\x0b\x32 .grakn.protocol.Query.Define.ReqH\x00R\tdefineReq\x12G\n\x0cundefine_req\x18\x65 \x01(\x0b\x32\".grakn.protocol.Query.Undefine.ReqH\x00R\x0bundefineReq\x12>\n\tmatch_req\x18\x66 \x01(\x0b\x32\x1f.grakn.protocol.Query.Match.ReqH\x00R\x08matchReq\x12Z\n\x13match_aggregate_req\x18g \x01(\x0b\x32(.grakn.protocol.Query.MatchAggregate.ReqH\x00R\x11matchAggregateReq\x12N\n\x0fmatch_group_req\x18h \x01(\x0b\x32$.grakn.protocol.Query.MatchGroup.ReqH\x00R\rmatchGroupReq\x12j\n\x19match_group_aggregate_req\x18i \x01(\x0b\x32-.grakn.protocol.Query.MatchGroupAggregate.ReqH\x00R\x16matchGroupAggregateReq\x12\x41\n\ninsert_req\x18j \x01(\x0b\x32 .grakn.protocol.Query.Insert.ReqH\x00R\tinsertReq\x12\x41\n\ndelete_req\x18k \x01(\x0b\x32 .grakn.protocol.Query.Delete.ReqH\x00R\tdeleteReq\x12\x41\n\nupdate_req\x18l \x01(\x0b\x32 .grakn.protocol.Query.Update.ReqH\x00R\tupdateReqB\x05\n\x03req\x1a\xb9\x05\n\x03Res\x12\x41\n\ndefine_res\x18\x64 \x01(\x0b\x32 .grakn.protocol.Query.Define.ResH\x00R\tdefineRes\x12G\n\x0cundefine_res\x18\x65 \x01(\x0b\x32\".grakn.protocol.Query.Undefine.ResH\x00R\x0bundefineRes\x12>\n\tmatch_res\x18\x66 \x01(\x0b\x32\x1f.grakn.protocol.Query.Match.ResH\x00R\x08matchRes\x12Z\n\x13match_aggregate_res\x18g \x01(\x0b\x32(.grakn.protocol.Query.MatchAggregate.ResH\x00R\x11matchAggregateRes\x12N\n\x0fmatch_group_res\x18h \x01(\x0b\x32$.grakn.protocol.Query.MatchGroup.ResH\x00R\rmatchGroupRes\x12j\n\x19match_group_aggregate_res\x18i \x01(\x0b\x32-.grakn.protocol.Query.MatchGroupAggregate.ResH\x00R\x16matchGroupAggregateRes\x12\x41\n\ninsert_res\x18j \x01(\x0b\x32 .grakn.protocol.Query.Insert.ResH\x00R\tinsertRes\x12\x41\n\ndelete_res\x18k \x01(\x0b\x32 .grakn.protocol.Query.Delete.ResH\x00R\tdeleteRes\x12\x41\n\nupdate_res\x18l \x01(\x0b\x32 .grakn.protocol.Query.Update.ResH\x00R\tupdateResB\x05\n\x03res\x1a\x61\n\x05Match\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a\x65\n\x0eMatchAggregate\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x36\n\x03Res\x12/\n\x06\x61nswer\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.NumericR\x06\x61nswer\x1ak\n\nMatchGroup\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a@\n\x03Res\x12\x39\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1f.grakn.protocol.ConceptMapGroupR\x07\x61nswers\x1aq\n\x13MatchGroupAggregate\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a=\n\x03Res\x12\x36\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1c.grakn.protocol.NumericGroupR\x07\x61nswers\x1a\x62\n\x06Insert\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a,\n\x06\x44\x65lete\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03Res\x1a\x62\n\x06Update\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a,\n\x06\x44\x65\x66ine\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03Res\x1a.\n\x08Undefine\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03ResB\x1c\n\x0egrakn.protocolB\nQueryProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_answer__pb2.DESCRIPTOR,protobuf_dot_options__pb2.DESCRIPTOR,])




_QUERY_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='grakn.protocol.Query.Req.options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='define_req', full_name='grakn.protocol.Query.Req.define_req', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defineReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undefine_req', full_name='grakn.protocol.Query.Req.undefine_req', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='undefineReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_req', full_name='grakn.protocol.Query.Req.match_req', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_aggregate_req', full_name='grakn.protocol.Query.Req.match_aggregate_req', index=4,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchAggregateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_req', full_name='grakn.protocol.Query.Req.match_group_req', index=5,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_aggregate_req', full_name='grakn.protocol.Query.Req.match_group_aggregate_req', index=6,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupAggregateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_req', full_name='grakn.protocol.Query.Req.insert_req', index=7,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='insertReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_req', full_name='grakn.protocol.Query.Req.delete_req', index=8,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deleteReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_req', full_name='grakn.protocol.Query.Req.update_req', index=9,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Query.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=98,
  serialized_end=846,
)

_QUERY_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='define_res', full_name='grakn.protocol.Query.Res.define_res', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defineRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undefine_res', full_name='grakn.protocol.Query.Res.undefine_res', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='undefineRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_res', full_name='grakn.protocol.Query.Res.match_res', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_aggregate_res', full_name='grakn.protocol.Query.Res.match_aggregate_res', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchAggregateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_res', full_name='grakn.protocol.Query.Res.match_group_res', index=4,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_aggregate_res', full_name='grakn.protocol.Query.Res.match_group_aggregate_res', index=5,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupAggregateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_res', full_name='grakn.protocol.Query.Res.insert_res', index=6,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='insertRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_res', full_name='grakn.protocol.Query.Res.delete_res', index=7,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deleteRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_res', full_name='grakn.protocol.Query.Res.update_res', index=8,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Query.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=849,
  serialized_end=1546,
)

_QUERY_MATCH_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Match.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Match.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCH_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Match.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Match.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='grakn.protocol.Query.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCH_REQ, _QUERY_MATCH_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1645,
)

_QUERY_MATCHAGGREGATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchAggregate.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchAggregate.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHAGGREGATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchAggregate.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer', full_name='grakn.protocol.Query.MatchAggregate.Res.answer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answer', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1694,
  serialized_end=1748,
)

_QUERY_MATCHAGGREGATE = _descriptor.Descriptor(
  name='MatchAggregate',
  full_name='grakn.protocol.Query.MatchAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHAGGREGATE_REQ, _QUERY_MATCHAGGREGATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=1748,
)

_QUERY_MATCHGROUP_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchGroup.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchGroup.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHGROUP_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchGroup.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.MatchGroup.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1857,
)

_QUERY_MATCHGROUP = _descriptor.Descriptor(
  name='MatchGroup',
  full_name='grakn.protocol.Query.MatchGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHGROUP_REQ, _QUERY_MATCHGROUP_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1857,
)

_QUERY_MATCHGROUPAGGREGATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchGroupAggregate.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchGroupAggregate.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHGROUPAGGREGATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchGroupAggregate.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.MatchGroupAggregate.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=1972,
)

_QUERY_MATCHGROUPAGGREGATE = _descriptor.Descriptor(
  name='MatchGroupAggregate',
  full_name='grakn.protocol.Query.MatchGroupAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHGROUPAGGREGATE_REQ, _QUERY_MATCHGROUPAGGREGATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1972,
)

_QUERY_INSERT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Insert.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Insert.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_INSERT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Insert.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Insert.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_INSERT = _descriptor.Descriptor(
  name='Insert',
  full_name='grakn.protocol.Query.Insert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_INSERT_REQ, _QUERY_INSERT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2072,
)

_QUERY_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Delete.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Query.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_DELETE_REQ, _QUERY_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2074,
  serialized_end=2118,
)

_QUERY_UPDATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Update.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Update.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_UPDATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Update.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Update.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_UPDATE = _descriptor.Descriptor(
  name='Update',
  full_name='grakn.protocol.Query.Update',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_UPDATE_REQ, _QUERY_UPDATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2218,
)

_QUERY_DEFINE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Define.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Define.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_DEFINE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Define.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_DEFINE = _descriptor.Descriptor(
  name='Define',
  full_name='grakn.protocol.Query.Define',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_DEFINE_REQ, _QUERY_DEFINE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2264,
)

_QUERY_UNDEFINE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Undefine.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Undefine.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_UNDEFINE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Undefine.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_UNDEFINE = _descriptor.Descriptor(
  name='Undefine',
  full_name='grakn.protocol.Query.Undefine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_UNDEFINE_REQ, _QUERY_UNDEFINE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2266,
  serialized_end=2312,
)

_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='grakn.protocol.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_REQ, _QUERY_RES, _QUERY_MATCH, _QUERY_MATCHAGGREGATE, _QUERY_MATCHGROUP, _QUERY_MATCHGROUPAGGREGATE, _QUERY_INSERT, _QUERY_DELETE, _QUERY_UPDATE, _QUERY_DEFINE, _QUERY_UNDEFINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=2312,
)

_QUERY_REQ.fields_by_name['options'].message_type = protobuf_dot_options__pb2._OPTIONS
_QUERY_REQ.fields_by_name['define_req'].message_type = _QUERY_DEFINE_REQ
_QUERY_REQ.fields_by_name['undefine_req'].message_type = _QUERY_UNDEFINE_REQ
_QUERY_REQ.fields_by_name['match_req'].message_type = _QUERY_MATCH_REQ
_QUERY_REQ.fields_by_name['match_aggregate_req'].message_type = _QUERY_MATCHAGGREGATE_REQ
_QUERY_REQ.fields_by_name['match_group_req'].message_type = _QUERY_MATCHGROUP_REQ
_QUERY_REQ.fields_by_name['match_group_aggregate_req'].message_type = _QUERY_MATCHGROUPAGGREGATE_REQ
_QUERY_REQ.fields_by_name['insert_req'].message_type = _QUERY_INSERT_REQ
_QUERY_REQ.fields_by_name['delete_req'].message_type = _QUERY_DELETE_REQ
_QUERY_REQ.fields_by_name['update_req'].message_type = _QUERY_UPDATE_REQ
_QUERY_REQ.containing_type = _QUERY
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['define_req'])
_QUERY_REQ.fields_by_name['define_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['undefine_req'])
_QUERY_REQ.fields_by_name['undefine_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_req'])
_QUERY_REQ.fields_by_name['match_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_aggregate_req'])
_QUERY_REQ.fields_by_name['match_aggregate_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_group_req'])
_QUERY_REQ.fields_by_name['match_group_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_group_aggregate_req'])
_QUERY_REQ.fields_by_name['match_group_aggregate_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['insert_req'])
_QUERY_REQ.fields_by_name['insert_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['delete_req'])
_QUERY_REQ.fields_by_name['delete_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['update_req'])
_QUERY_REQ.fields_by_name['update_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_RES.fields_by_name['define_res'].message_type = _QUERY_DEFINE_RES
_QUERY_RES.fields_by_name['undefine_res'].message_type = _QUERY_UNDEFINE_RES
_QUERY_RES.fields_by_name['match_res'].message_type = _QUERY_MATCH_RES
_QUERY_RES.fields_by_name['match_aggregate_res'].message_type = _QUERY_MATCHAGGREGATE_RES
_QUERY_RES.fields_by_name['match_group_res'].message_type = _QUERY_MATCHGROUP_RES
_QUERY_RES.fields_by_name['match_group_aggregate_res'].message_type = _QUERY_MATCHGROUPAGGREGATE_RES
_QUERY_RES.fields_by_name['insert_res'].message_type = _QUERY_INSERT_RES
_QUERY_RES.fields_by_name['delete_res'].message_type = _QUERY_DELETE_RES
_QUERY_RES.fields_by_name['update_res'].message_type = _QUERY_UPDATE_RES
_QUERY_RES.containing_type = _QUERY
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['define_res'])
_QUERY_RES.fields_by_name['define_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['undefine_res'])
_QUERY_RES.fields_by_name['undefine_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_res'])
_QUERY_RES.fields_by_name['match_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_aggregate_res'])
_QUERY_RES.fields_by_name['match_aggregate_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_group_res'])
_QUERY_RES.fields_by_name['match_group_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_group_aggregate_res'])
_QUERY_RES.fields_by_name['match_group_aggregate_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['insert_res'])
_QUERY_RES.fields_by_name['insert_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['delete_res'])
_QUERY_RES.fields_by_name['delete_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['update_res'])
_QUERY_RES.fields_by_name['update_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_MATCH_REQ.containing_type = _QUERY_MATCH
_QUERY_MATCH_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_MATCH_RES.containing_type = _QUERY_MATCH
_QUERY_MATCH.containing_type = _QUERY
_QUERY_MATCHAGGREGATE_REQ.containing_type = _QUERY_MATCHAGGREGATE
_QUERY_MATCHAGGREGATE_RES.fields_by_name['answer'].message_type = protobuf_dot_answer__pb2._NUMERIC
_QUERY_MATCHAGGREGATE_RES.containing_type = _QUERY_MATCHAGGREGATE
_QUERY_MATCHAGGREGATE.containing_type = _QUERY
_QUERY_MATCHGROUP_REQ.containing_type = _QUERY_MATCHGROUP
_QUERY_MATCHGROUP_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAPGROUP
_QUERY_MATCHGROUP_RES.containing_type = _QUERY_MATCHGROUP
_QUERY_MATCHGROUP.containing_type = _QUERY
_QUERY_MATCHGROUPAGGREGATE_REQ.containing_type = _QUERY_MATCHGROUPAGGREGATE
_QUERY_MATCHGROUPAGGREGATE_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._NUMERICGROUP
_QUERY_MATCHGROUPAGGREGATE_RES.containing_type = _QUERY_MATCHGROUPAGGREGATE
_QUERY_MATCHGROUPAGGREGATE.containing_type = _QUERY
_QUERY_INSERT_REQ.containing_type = _QUERY_INSERT
_QUERY_INSERT_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_INSERT_RES.containing_type = _QUERY_INSERT
_QUERY_INSERT.containing_type = _QUERY
_QUERY_DELETE_REQ.containing_type = _QUERY_DELETE
_QUERY_DELETE_RES.containing_type = _QUERY_DELETE
_QUERY_DELETE.containing_type = _QUERY
_QUERY_UPDATE_REQ.containing_type = _QUERY_UPDATE
_QUERY_UPDATE_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_UPDATE_RES.containing_type = _QUERY_UPDATE
_QUERY_UPDATE.containing_type = _QUERY
_QUERY_DEFINE_REQ.containing_type = _QUERY_DEFINE
_QUERY_DEFINE_RES.containing_type = _QUERY_DEFINE
_QUERY_DEFINE.containing_type = _QUERY
_QUERY_UNDEFINE_REQ.containing_type = _QUERY_UNDEFINE
_QUERY_UNDEFINE_RES.containing_type = _QUERY_UNDEFINE
_QUERY_UNDEFINE.containing_type = _QUERY
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _QUERY_REQ,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _QUERY_RES,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Res)
    ))
  ,

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCH_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCH_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCH,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match)
    ))
  ,

  MatchAggregate = _reflection.GeneratedProtocolMessageType('MatchAggregate', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHAGGREGATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHAGGREGATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHAGGREGATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate)
    ))
  ,

  MatchGroup = _reflection.GeneratedProtocolMessageType('MatchGroup', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUP_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUP_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHGROUP,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup)
    ))
  ,

  MatchGroupAggregate = _reflection.GeneratedProtocolMessageType('MatchGroupAggregate', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate)
    ))
  ,

  Insert = _reflection.GeneratedProtocolMessageType('Insert', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_INSERT_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_INSERT_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_INSERT,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DELETE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DELETE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_DELETE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete)
    ))
  ,

  Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UPDATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UPDATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_UPDATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update)
    ))
  ,

  Define = _reflection.GeneratedProtocolMessageType('Define', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DEFINE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DEFINE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_DEFINE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define)
    ))
  ,

  Undefine = _reflection.GeneratedProtocolMessageType('Undefine', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UNDEFINE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UNDEFINE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_UNDEFINE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine)
    ))
  ,
  DESCRIPTOR = _QUERY,
  __module__ = 'protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Query)
  ))
_sym_db.RegisterMessage(Query)
_sym_db.RegisterMessage(Query.Req)
_sym_db.RegisterMessage(Query.Res)
_sym_db.RegisterMessage(Query.Match)
_sym_db.RegisterMessage(Query.Match.Req)
_sym_db.RegisterMessage(Query.Match.Res)
_sym_db.RegisterMessage(Query.MatchAggregate)
_sym_db.RegisterMessage(Query.MatchAggregate.Req)
_sym_db.RegisterMessage(Query.MatchAggregate.Res)
_sym_db.RegisterMessage(Query.MatchGroup)
_sym_db.RegisterMessage(Query.MatchGroup.Req)
_sym_db.RegisterMessage(Query.MatchGroup.Res)
_sym_db.RegisterMessage(Query.MatchGroupAggregate)
_sym_db.RegisterMessage(Query.MatchGroupAggregate.Req)
_sym_db.RegisterMessage(Query.MatchGroupAggregate.Res)
_sym_db.RegisterMessage(Query.Insert)
_sym_db.RegisterMessage(Query.Insert.Req)
_sym_db.RegisterMessage(Query.Insert.Res)
_sym_db.RegisterMessage(Query.Delete)
_sym_db.RegisterMessage(Query.Delete.Req)
_sym_db.RegisterMessage(Query.Delete.Res)
_sym_db.RegisterMessage(Query.Update)
_sym_db.RegisterMessage(Query.Update.Req)
_sym_db.RegisterMessage(Query.Update.Res)
_sym_db.RegisterMessage(Query.Define)
_sym_db.RegisterMessage(Query.Define.Req)
_sym_db.RegisterMessage(Query.Define.Res)
_sym_db.RegisterMessage(Query.Undefine)
_sym_db.RegisterMessage(Query.Undefine.Req)
_sym_db.RegisterMessage(Query.Undefine.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
