# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/grakn.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import database_pb2 as protobuf_dot_database__pb2
from grakn_protocol.protobuf import session_pb2 as protobuf_dot_session__pb2
from grakn_protocol.protobuf import transaction_pb2 as protobuf_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/grakn.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\nGraknProto'),
  serialized_pb=_b('\n\x14protobuf/grakn.proto\x12\x0egrakn.protocol\x1a\x17protobuf/database.proto\x1a\x16protobuf/session.proto\x1a\x1aprotobuf/transaction.proto2\xcf\x05\n\x05Grakn\x12\x61\n\x11\x64\x61tabase_contains\x12%.grakn.protocol.Database.Contains.Req\x1a%.grakn.protocol.Database.Contains.Res\x12[\n\x0f\x64\x61tabase_create\x12#.grakn.protocol.Database.Create.Req\x1a#.grakn.protocol.Database.Create.Res\x12R\n\x0c\x64\x61tabase_all\x12 .grakn.protocol.Database.All.Req\x1a .grakn.protocol.Database.All.Res\x12[\n\x0f\x64\x61tabase_delete\x12#.grakn.protocol.Database.Delete.Req\x1a#.grakn.protocol.Database.Delete.Res\x12R\n\x0csession_open\x12 .grakn.protocol.Session.Open.Req\x1a .grakn.protocol.Session.Open.Res\x12U\n\rsession_close\x12!.grakn.protocol.Session.Close.Req\x1a!.grakn.protocol.Session.Close.Res\x12U\n\rsession_pulse\x12!.grakn.protocol.Session.Pulse.Req\x1a!.grakn.protocol.Session.Pulse.Res\x12S\n\x0btransaction\x12\x1f.grakn.protocol.Transaction.Req\x1a\x1f.grakn.protocol.Transaction.Res(\x01\x30\x01\x42\x1c\n\x0egrakn.protocolB\nGraknProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_database__pb2.DESCRIPTOR,protobuf_dot_session__pb2.DESCRIPTOR,protobuf_dot_transaction__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_GRAKN = _descriptor.ServiceDescriptor(
  name='Grakn',
  full_name='grakn.protocol.Grakn',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=118,
  serialized_end=837,
  methods=[
  _descriptor.MethodDescriptor(
    name='database_contains',
    full_name='grakn.protocol.Grakn.database_contains',
    index=0,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_CONTAINS_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_CONTAINS_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_create',
    full_name='grakn.protocol.Grakn.database_create',
    index=1,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_CREATE_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_CREATE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_all',
    full_name='grakn.protocol.Grakn.database_all',
    index=2,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_ALL_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_ALL_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_delete',
    full_name='grakn.protocol.Grakn.database_delete',
    index=3,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_DELETE_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_DELETE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_open',
    full_name='grakn.protocol.Grakn.session_open',
    index=4,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_OPEN_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_OPEN_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_close',
    full_name='grakn.protocol.Grakn.session_close',
    index=5,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_CLOSE_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_CLOSE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_pulse',
    full_name='grakn.protocol.Grakn.session_pulse',
    index=6,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_PULSE_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_PULSE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='transaction',
    full_name='grakn.protocol.Grakn.transaction',
    index=7,
    containing_service=None,
    input_type=protobuf_dot_transaction__pb2._TRANSACTION_REQ,
    output_type=protobuf_dot_transaction__pb2._TRANSACTION_RES,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRAKN)

DESCRIPTOR.services_by_name['Grakn'] = _GRAKN

# @@protoc_insertion_point(module_scope)
