# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/database.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/database.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\rDatabaseProto'),
  serialized_pb=_b('\n\x1fprotobuf/cluster/database.proto\x12\x16grakn.protocol.cluster\"\xa5\x03\n\x08\x44\x61tabase\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x08replicas\x18\x02 \x03(\x0b\x32(.grakn.protocol.cluster.Database.ReplicaR\x08replicas\x1a\x82\x01\n\x07Replica\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x18\n\x07primary\x18\x02 \x01(\x08R\x07primary\x12/\n\x13preferred_secondary\x18\x03 \x01(\x08R\x12preferredSecondary\x12\x12\n\x04term\x18\x04 \x01(\x03R\x04term\x1a\x65\n\x03Get\x1a\x19\n\x03Req\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a\x43\n\x03Res\x12<\n\x08\x64\x61tabase\x18\x01 \x01(\x0b\x32 .grakn.protocol.cluster.DatabaseR\x08\x64\x61tabase\x1aS\n\x03\x41ll\x1a\x05\n\x03Req\x1a\x45\n\x03Res\x12>\n\tdatabases\x18\x01 \x03(\x0b\x32 .grakn.protocol.cluster.DatabaseR\tdatabasesB\'\n\x16grakn.protocol.clusterB\rDatabaseProtob\x06proto3')
)




_DATABASE_REPLICA = _descriptor.Descriptor(
  name='Replica',
  full_name='grakn.protocol.cluster.Database.Replica',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='grakn.protocol.cluster.Database.Replica.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary', full_name='grakn.protocol.cluster.Database.Replica.primary', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primary', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_secondary', full_name='grakn.protocol.cluster.Database.Replica.preferred_secondary', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='preferredSecondary', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term', full_name='grakn.protocol.cluster.Database.Replica.term', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='term', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=293,
)

_DATABASE_GET_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Database.Get.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.cluster.Database.Get.Req.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=327,
)

_DATABASE_GET_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Database.Get.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='grakn.protocol.cluster.Database.Get.Res.database', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=396,
)

_DATABASE_GET = _descriptor.Descriptor(
  name='Get',
  full_name='grakn.protocol.cluster.Database.Get',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_GET_REQ, _DATABASE_GET_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=396,
)

_DATABASE_ALL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Database.All.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=307,
)

_DATABASE_ALL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Database.All.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='grakn.protocol.cluster.Database.All.Res.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='databases', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=481,
)

_DATABASE_ALL = _descriptor.Descriptor(
  name='All',
  full_name='grakn.protocol.cluster.Database.All',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_ALL_REQ, _DATABASE_ALL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=481,
)

_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='grakn.protocol.cluster.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.cluster.Database.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replicas', full_name='grakn.protocol.cluster.Database.replicas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='replicas', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_REPLICA, _DATABASE_GET, _DATABASE_ALL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=481,
)

_DATABASE_REPLICA.containing_type = _DATABASE
_DATABASE_GET_REQ.containing_type = _DATABASE_GET
_DATABASE_GET_RES.fields_by_name['database'].message_type = _DATABASE
_DATABASE_GET_RES.containing_type = _DATABASE_GET
_DATABASE_GET.containing_type = _DATABASE
_DATABASE_ALL_REQ.containing_type = _DATABASE_ALL
_DATABASE_ALL_RES.fields_by_name['databases'].message_type = _DATABASE
_DATABASE_ALL_RES.containing_type = _DATABASE_ALL
_DATABASE_ALL.containing_type = _DATABASE
_DATABASE.fields_by_name['replicas'].message_type = _DATABASE_REPLICA
DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), dict(

  Replica = _reflection.GeneratedProtocolMessageType('Replica', (_message.Message,), dict(
    DESCRIPTOR = _DATABASE_REPLICA,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Replica)
    ))
  ,

  Get = _reflection.GeneratedProtocolMessageType('Get', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_GET_REQ,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_GET_RES,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_GET,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get)
    ))
  ,

  All = _reflection.GeneratedProtocolMessageType('All', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_REQ,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_RES,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_ALL,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All)
    ))
  ,
  DESCRIPTOR = _DATABASE,
  __module__ = 'protobuf.cluster.database_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database)
  ))
_sym_db.RegisterMessage(Database)
_sym_db.RegisterMessage(Database.Replica)
_sym_db.RegisterMessage(Database.Get)
_sym_db.RegisterMessage(Database.Get.Req)
_sym_db.RegisterMessage(Database.Get.Res)
_sym_db.RegisterMessage(Database.All)
_sym_db.RegisterMessage(Database.All.Req)
_sym_db.RegisterMessage(Database.All.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
