# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/concept.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/concept.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\014ConceptProto'),
  serialized_pb=_b('\n\x16protobuf/concept.proto\x12\x0egrakn.protocol\"\xf4\x0c\n\x0e\x43onceptManager\x1a\xf7\x03\n\x03Req\x12^\n\x12get_thing_type_req\x18\x01 \x01(\x0b\x32/.grakn.protocol.ConceptManager.GetThingType.ReqH\x00R\x0fgetThingTypeReq\x12Q\n\rget_thing_req\x18\x02 \x01(\x0b\x32+.grakn.protocol.ConceptManager.GetThing.ReqH\x00R\x0bgetThingReq\x12\x61\n\x13put_entity_type_req\x18\x03 \x01(\x0b\x32\x30.grakn.protocol.ConceptManager.PutEntityType.ReqH\x00R\x10putEntityTypeReq\x12j\n\x16put_attribute_type_req\x18\x04 \x01(\x0b\x32\x33.grakn.protocol.ConceptManager.PutAttributeType.ReqH\x00R\x13putAttributeTypeReq\x12g\n\x15put_relation_type_req\x18\x05 \x01(\x0b\x32\x32.grakn.protocol.ConceptManager.PutRelationType.ReqH\x00R\x12putRelationTypeReqB\x05\n\x03req\x1a\xf7\x03\n\x03Res\x12^\n\x12get_thing_type_res\x18\x01 \x01(\x0b\x32/.grakn.protocol.ConceptManager.GetThingType.ResH\x00R\x0fgetThingTypeRes\x12Q\n\rget_thing_res\x18\x02 \x01(\x0b\x32+.grakn.protocol.ConceptManager.GetThing.ResH\x00R\x0bgetThingRes\x12\x61\n\x13put_entity_type_res\x18\x03 \x01(\x0b\x32\x30.grakn.protocol.ConceptManager.PutEntityType.ResH\x00R\x10putEntityTypeRes\x12j\n\x16put_attribute_type_res\x18\x04 \x01(\x0b\x32\x33.grakn.protocol.ConceptManager.PutAttributeType.ResH\x00R\x13putAttributeTypeRes\x12g\n\x15put_relation_type_res\x18\x05 \x01(\x0b\x32\x32.grakn.protocol.ConceptManager.PutRelationType.ResH\x00R\x12putRelationTypeResB\x05\n\x03res\x1ap\n\x0cGetThingType\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x43\n\x03Res\x12\x35\n\nthing_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\tthingTypeB\x05\n\x03res\x1a`\n\x08GetThing\x1a\x17\n\x03Req\x12\x10\n\x03iid\x18\x01 \x01(\x0cR\x03iid\x1a;\n\x03Res\x12-\n\x05thing\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingH\x00R\x05thingB\x05\n\x03res\x1aj\n\rPutEntityType\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a<\n\x03Res\x12\x35\n\x0b\x65ntity_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\nentityType\x1a\xbb\x01\n\x10PutAttributeType\x1a\x63\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x46\n\nvalue_type\x18\x02 \x01(\x0e\x32\'.grakn.protocol.AttributeType.ValueTypeR\tvalueType\x1a\x42\n\x03Res\x12;\n\x0e\x61ttribute_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\rattributeType\x1ap\n\x0fPutRelationType\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a@\n\x03Res\x12\x39\n\rrelation_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x0crelationType\"o\n\x07\x43oncept\x12-\n\x05thing\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingH\x00R\x05thing\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\x04typeB\t\n\x07\x63oncept\"\xec\x19\n\x05Thing\x12\x10\n\x03iid\x18\x01 \x01(\x0cR\x03iid\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x04type\x12\x35\n\x05value\x18\x03 \x01(\x0b\x32\x1f.grakn.protocol.Attribute.ValueR\x05value\x1a\xe0\t\n\x03Req\x12\x10\n\x03iid\x18\x01 \x01(\x0cR\x03iid\x12L\n\x10thing_delete_req\x18\x64 \x01(\x0b\x32 .grakn.protocol.Thing.Delete.ReqH\x00R\x0ethingDeleteReq\x12P\n\x12thing_get_type_req\x18\x65 \x01(\x0b\x32!.grakn.protocol.Thing.GetType.ReqH\x00R\x0fthingGetTypeReq\x12Y\n\x15thing_is_inferred_req\x18\x66 \x01(\x0b\x32$.grakn.protocol.Thing.IsInferred.ReqH\x00R\x12thingIsInferredReq\x12M\n\x11thing_set_has_req\x18g \x01(\x0b\x32 .grakn.protocol.Thing.SetHas.ReqH\x00R\x0ethingSetHasReq\x12S\n\x13thing_unset_has_req\x18h \x01(\x0b\x32\".grakn.protocol.Thing.UnsetHas.ReqH\x00R\x10thingUnsetHasReq\x12M\n\x11thing_get_has_req\x18i \x01(\x0b\x32 .grakn.protocol.Thing.GetHas.ReqH\x00R\x0ethingGetHasReq\x12_\n\x17thing_get_relations_req\x18j \x01(\x0b\x32&.grakn.protocol.Thing.GetRelations.ReqH\x00R\x14thingGetRelationsReq\x12S\n\x13thing_get_plays_req\x18k \x01(\x0b\x32\".grakn.protocol.Thing.GetPlays.ReqH\x00R\x10thingGetPlaysReq\x12`\n\x17relation_add_player_req\x18\xc8\x01 \x01(\x0b\x32&.grakn.protocol.Relation.AddPlayer.ReqH\x00R\x14relationAddPlayerReq\x12i\n\x1arelation_remove_player_req\x18\xc9\x01 \x01(\x0b\x32).grakn.protocol.Relation.RemovePlayer.ReqH\x00R\x17relationRemovePlayerReq\x12\x63\n\x18relation_get_players_req\x18\xca\x01 \x01(\x0b\x32\'.grakn.protocol.Relation.GetPlayers.ReqH\x00R\x15relationGetPlayersReq\x12\x84\x01\n%relation_get_players_by_role_type_req\x18\xcb\x01 \x01(\x0b\x32\x31.grakn.protocol.Relation.GetPlayersByRoleType.ReqH\x00R\x1frelationGetPlayersByRoleTypeReq\x12\x63\n\x18\x61ttribute_get_owners_req\x18\xac\x02 \x01(\x0b\x32\'.grakn.protocol.Attribute.GetOwners.ReqH\x00R\x15\x61ttributeGetOwnersReqB\x05\n\x03req\x1a\xce\t\n\x03Res\x12L\n\x10thing_delete_res\x18\x64 \x01(\x0b\x32 .grakn.protocol.Thing.Delete.ResH\x00R\x0ethingDeleteRes\x12P\n\x12thing_get_type_res\x18\x65 \x01(\x0b\x32!.grakn.protocol.Thing.GetType.ResH\x00R\x0fthingGetTypeRes\x12Y\n\x15thing_is_inferred_res\x18\x66 \x01(\x0b\x32$.grakn.protocol.Thing.IsInferred.ResH\x00R\x12thingIsInferredRes\x12M\n\x11thing_set_has_res\x18g \x01(\x0b\x32 .grakn.protocol.Thing.SetHas.ResH\x00R\x0ethingSetHasRes\x12S\n\x13thing_unset_has_res\x18h \x01(\x0b\x32\".grakn.protocol.Thing.UnsetHas.ResH\x00R\x10thingUnsetHasRes\x12M\n\x11thing_get_has_res\x18i \x01(\x0b\x32 .grakn.protocol.Thing.GetHas.ResH\x00R\x0ethingGetHasRes\x12_\n\x17thing_get_relations_res\x18j \x01(\x0b\x32&.grakn.protocol.Thing.GetRelations.ResH\x00R\x14thingGetRelationsRes\x12S\n\x13thing_get_plays_res\x18k \x01(\x0b\x32\".grakn.protocol.Thing.GetPlays.ResH\x00R\x10thingGetPlaysRes\x12`\n\x17relation_add_player_res\x18\xc8\x01 \x01(\x0b\x32&.grakn.protocol.Relation.AddPlayer.ResH\x00R\x14relationAddPlayerRes\x12i\n\x1arelation_remove_player_res\x18\xc9\x01 \x01(\x0b\x32).grakn.protocol.Relation.RemovePlayer.ResH\x00R\x17relationRemovePlayerRes\x12\x63\n\x18relation_get_players_res\x18\xca\x01 \x01(\x0b\x32\'.grakn.protocol.Relation.GetPlayers.ResH\x00R\x15relationGetPlayersRes\x12\x84\x01\n%relation_get_players_by_role_type_res\x18\xcb\x01 \x01(\x0b\x32\x31.grakn.protocol.Relation.GetPlayersByRoleType.ResH\x00R\x1frelationGetPlayersByRoleTypeRes\x12\x63\n\x18\x61ttribute_get_owners_res\x18\xac\x02 \x01(\x0b\x32\'.grakn.protocol.Attribute.GetOwners.ResH\x00R\x15\x61ttributeGetOwnersResB\x05\n\x03res\x1a\x16\n\x06\x44\x65lete\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a\x36\n\nIsInferred\x1a\x05\n\x03Req\x1a!\n\x03Res\x12\x1a\n\x08inferred\x18\x01 \x01(\x08R\x08inferred\x1aL\n\x07GetType\x1a\x05\n\x03Req\x1a:\n\x03Res\x12\x33\n\nthing_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\tthingType\x1aK\n\x06SetHas\x1a:\n\x03Req\x12\x33\n\tattribute\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingR\tattribute\x1a\x05\n\x03Res\x1aM\n\x08UnsetHas\x1a:\n\x03Req\x12\x33\n\tattribute\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingR\tattribute\x1a\x05\n\x03Res\x1a\xa9\x01\n\x06GetHas\x1a\x61\n\x03Req\x12=\n\x0f\x61ttribute_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x0e\x61ttributeTypes\x12\x1b\n\tkeys_only\x18\x02 \x01(\x08R\x08keysOnly\x1a<\n\x03Res\x12\x35\n\nattributes\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\nattributes\x1aM\n\x08GetPlays\x1a\x05\n\x03Req\x1a:\n\x03Res\x12\x33\n\nrole_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\troleTypes\x1a\x86\x01\n\x0cGetRelations\x1a:\n\x03Req\x12\x33\n\nrole_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\troleTypes\x1a:\n\x03Res\x12\x33\n\trelations\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\trelations\"\x9f\x05\n\x08Relation\x1a~\n\nGetPlayers\x1a:\n\x03Req\x12\x33\n\nrole_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\troleTypes\x1a\x34\n\x03Res\x12-\n\x06things\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\x06things\x1a\x95\x02\n\x14GetPlayersByRoleType\x1av\n\x12RoleTypeWithPlayer\x12\x31\n\trole_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x08roleType\x12-\n\x06player\x18\x02 \x01(\x0b\x32\x15.grakn.protocol.ThingR\x06player\x1a\x05\n\x03Req\x1a~\n\x03Res\x12w\n\x17role_types_with_players\x18\x01 \x03(\x0b\x32@.grakn.protocol.Relation.GetPlayersByRoleType.RoleTypeWithPlayerR\x14roleTypesWithPlayers\x1a{\n\tAddPlayer\x1ag\n\x03Req\x12\x31\n\trole_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x08roleType\x12-\n\x06player\x18\x02 \x01(\x0b\x32\x15.grakn.protocol.ThingR\x06player\x1a\x05\n\x03Res\x1a~\n\x0cRemovePlayer\x1ag\n\x03Req\x12\x31\n\trole_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x08roleType\x12-\n\x06player\x18\x02 \x01(\x0b\x32\x15.grakn.protocol.ThingR\x06player\x1a\x05\n\x03Res\"\xaf\x02\n\tAttribute\x1a\x89\x01\n\tGetOwners\x1a\x46\n\x03Req\x12\x35\n\nthing_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\tthingTypeB\x08\n\x06\x66ilter\x1a\x34\n\x03Res\x12-\n\x06things\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\x06things\x1a\x95\x01\n\x05Value\x12\x18\n\x06string\x18\x01 \x01(\tH\x00R\x06string\x12\x1a\n\x07\x62oolean\x18\x02 \x01(\x08H\x00R\x07\x62oolean\x12\x14\n\x04long\x18\x03 \x01(\x03H\x00R\x04long\x12\x18\n\x06\x64ouble\x18\x04 \x01(\x01H\x00R\x06\x64ouble\x12\x1d\n\tdate_time\x18\x05 \x01(\x03H\x00R\x08\x64\x61teTimeB\x07\n\x05value\"\xfb\x36\n\x04Type\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x14\n\x05scope\x18\x02 \x01(\tR\x05scope\x12\x39\n\x08\x65ncoding\x18\x03 \x01(\x0e\x32\x1d.grakn.protocol.Type.EncodingR\x08\x65ncoding\x12\x46\n\nvalue_type\x18\x04 \x01(\x0e\x32\'.grakn.protocol.AttributeType.ValueTypeR\tvalueType\x12\x12\n\x04root\x18\x05 \x01(\x08R\x04root\x1a\xe4\x18\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x14\n\x05scope\x18\x02 \x01(\tR\x05scope\x12I\n\x0ftype_delete_req\x18\x64 \x01(\x0b\x32\x1f.grakn.protocol.Type.Delete.ReqH\x00R\rtypeDeleteReq\x12P\n\x12type_set_label_req\x18\x65 \x01(\x0b\x32!.grakn.protocol.Type.SetLabel.ReqH\x00R\x0ftypeSetLabelReq\x12V\n\x14type_is_abstract_req\x18\x66 \x01(\x0b\x32#.grakn.protocol.Type.IsAbstract.ReqH\x00R\x11typeIsAbstractReq\x12\\\n\x16type_get_supertype_req\x18g \x01(\x0b\x32%.grakn.protocol.Type.GetSupertype.ReqH\x00R\x13typeGetSupertypeReq\x12\\\n\x16type_set_supertype_req\x18h \x01(\x0b\x32%.grakn.protocol.Type.SetSupertype.ReqH\x00R\x13typeSetSupertypeReq\x12_\n\x17type_get_supertypes_req\x18i \x01(\x0b\x32&.grakn.protocol.Type.GetSupertypes.ReqH\x00R\x14typeGetSupertypesReq\x12Y\n\x15type_get_subtypes_req\x18j \x01(\x0b\x32$.grakn.protocol.Type.GetSubtypes.ReqH\x00R\x12typeGetSubtypesReq\x12t\n\x1frole_type_get_relation_type_req\x18\xc8\x01 \x01(\x0b\x32,.grakn.protocol.RoleType.GetRelationType.ReqH\x00R\x1aroleTypeGetRelationTypeReq\x12w\n role_type_get_relation_types_req\x18\xc9\x01 \x01(\x0b\x32-.grakn.protocol.RoleType.GetRelationTypes.ReqH\x00R\x1broleTypeGetRelationTypesReq\x12\x64\n\x19role_type_get_players_req\x18\xca\x01 \x01(\x0b\x32\'.grakn.protocol.RoleType.GetPlayers.ReqH\x00R\x15roleTypeGetPlayersReq\x12j\n\x1bthing_type_set_abstract_req\x18\xac\x02 \x01(\x0b\x32).grakn.protocol.ThingType.SetAbstract.ReqH\x00R\x17thingTypeSetAbstractReq\x12p\n\x1dthing_type_unset_abstract_req\x18\xad\x02 \x01(\x0b\x32+.grakn.protocol.ThingType.UnsetAbstract.ReqH\x00R\x19thingTypeUnsetAbstractReq\x12^\n\x17thing_type_set_owns_req\x18\xae\x02 \x01(\x0b\x32%.grakn.protocol.ThingType.SetOwns.ReqH\x00R\x13thingTypeSetOwnsReq\x12\x64\n\x19thing_type_unset_owns_req\x18\xaf\x02 \x01(\x0b\x32\'.grakn.protocol.ThingType.UnsetOwns.ReqH\x00R\x15thingTypeUnsetOwnsReq\x12\x61\n\x18thing_type_set_plays_req\x18\xb0\x02 \x01(\x0b\x32&.grakn.protocol.ThingType.SetPlays.ReqH\x00R\x14thingTypeSetPlaysReq\x12g\n\x1athing_type_unset_plays_req\x18\xb1\x02 \x01(\x0b\x32(.grakn.protocol.ThingType.UnsetPlays.ReqH\x00R\x16thingTypeUnsetPlaysReq\x12m\n\x1cthing_type_get_instances_req\x18\xb2\x02 \x01(\x0b\x32*.grakn.protocol.ThingType.GetInstances.ReqH\x00R\x18thingTypeGetInstancesReq\x12^\n\x17thing_type_get_owns_req\x18\xb3\x02 \x01(\x0b\x32%.grakn.protocol.ThingType.GetOwns.ReqH\x00R\x13thingTypeGetOwnsReq\x12\x61\n\x18thing_type_get_plays_req\x18\xb4\x02 \x01(\x0b\x32&.grakn.protocol.ThingType.GetPlays.ReqH\x00R\x14thingTypeGetPlaysReq\x12]\n\x16\x65ntity_type_create_req\x18\x90\x03 \x01(\x0b\x32%.grakn.protocol.EntityType.Create.ReqH\x00R\x13\x65ntityTypeCreateReq\x12\x63\n\x18relation_type_create_req\x18\xf4\x03 \x01(\x0b\x32\'.grakn.protocol.RelationType.Create.ReqH\x00R\x15relationTypeCreateReq\x12\x97\x01\n,relation_type_get_relates_for_role_label_req\x18\xf5\x03 \x01(\x0b\x32\x37.grakn.protocol.RelationType.GetRelatesForRoleLabel.ReqH\x00R%relationTypeGetRelatesForRoleLabelReq\x12p\n\x1drelation_type_set_relates_req\x18\xf6\x03 \x01(\x0b\x32+.grakn.protocol.RelationType.SetRelates.ReqH\x00R\x19relationTypeSetRelatesReq\x12v\n\x1frelation_type_unset_relates_req\x18\xf7\x03 \x01(\x0b\x32-.grakn.protocol.RelationType.UnsetRelates.ReqH\x00R\x1brelationTypeUnsetRelatesReq\x12p\n\x1drelation_type_get_relates_req\x18\xf8\x03 \x01(\x0b\x32+.grakn.protocol.RelationType.GetRelates.ReqH\x00R\x19relationTypeGetRelatesReq\x12]\n\x16\x61ttribute_type_put_req\x18\xd8\x04 \x01(\x0b\x32%.grakn.protocol.AttributeType.Put.ReqH\x00R\x13\x61ttributeTypePutReq\x12]\n\x16\x61ttribute_type_get_req\x18\xd9\x04 \x01(\x0b\x32%.grakn.protocol.AttributeType.Get.ReqH\x00R\x13\x61ttributeTypeGetReq\x12m\n\x1c\x61ttribute_type_get_regex_req\x18\xda\x04 \x01(\x0b\x32*.grakn.protocol.AttributeType.GetRegex.ReqH\x00R\x18\x61ttributeTypeGetRegexReq\x12m\n\x1c\x61ttribute_type_set_regex_req\x18\xdb\x04 \x01(\x0b\x32*.grakn.protocol.AttributeType.SetRegex.ReqH\x00R\x18\x61ttributeTypeSetRegexReq\x12p\n\x1d\x61ttribute_type_get_owners_req\x18\xdc\x04 \x01(\x0b\x32+.grakn.protocol.AttributeType.GetOwners.ReqH\x00R\x19\x61ttributeTypeGetOwnersReqB\x05\n\x03req\x1a\xb8\x18\n\x03Res\x12I\n\x0ftype_delete_res\x18\x64 \x01(\x0b\x32\x1f.grakn.protocol.Type.Delete.ResH\x00R\rtypeDeleteRes\x12P\n\x12type_set_label_res\x18\x65 \x01(\x0b\x32!.grakn.protocol.Type.SetLabel.ResH\x00R\x0ftypeSetLabelRes\x12V\n\x14type_is_abstract_res\x18\x66 \x01(\x0b\x32#.grakn.protocol.Type.IsAbstract.ResH\x00R\x11typeIsAbstractRes\x12\\\n\x16type_get_supertype_res\x18g \x01(\x0b\x32%.grakn.protocol.Type.GetSupertype.ResH\x00R\x13typeGetSupertypeRes\x12\\\n\x16type_set_supertype_res\x18h \x01(\x0b\x32%.grakn.protocol.Type.SetSupertype.ResH\x00R\x13typeSetSupertypeRes\x12_\n\x17type_get_supertypes_res\x18i \x01(\x0b\x32&.grakn.protocol.Type.GetSupertypes.ResH\x00R\x14typeGetSupertypesRes\x12Y\n\x15type_get_subtypes_res\x18j \x01(\x0b\x32$.grakn.protocol.Type.GetSubtypes.ResH\x00R\x12typeGetSubtypesRes\x12t\n\x1frole_type_get_relation_type_res\x18\xc8\x01 \x01(\x0b\x32,.grakn.protocol.RoleType.GetRelationType.ResH\x00R\x1aroleTypeGetRelationTypeRes\x12w\n role_type_get_relation_types_res\x18\xc9\x01 \x01(\x0b\x32-.grakn.protocol.RoleType.GetRelationTypes.ResH\x00R\x1broleTypeGetRelationTypesRes\x12\x64\n\x19role_type_get_players_res\x18\xca\x01 \x01(\x0b\x32\'.grakn.protocol.RoleType.GetPlayers.ResH\x00R\x15roleTypeGetPlayersRes\x12j\n\x1bthing_type_set_abstract_res\x18\xac\x02 \x01(\x0b\x32).grakn.protocol.ThingType.SetAbstract.ResH\x00R\x17thingTypeSetAbstractRes\x12p\n\x1dthing_type_unset_abstract_res\x18\xad\x02 \x01(\x0b\x32+.grakn.protocol.ThingType.UnsetAbstract.ResH\x00R\x19thingTypeUnsetAbstractRes\x12^\n\x17thing_type_set_owns_res\x18\xae\x02 \x01(\x0b\x32%.grakn.protocol.ThingType.SetOwns.ResH\x00R\x13thingTypeSetOwnsRes\x12\x64\n\x19thing_type_unset_owns_res\x18\xaf\x02 \x01(\x0b\x32\'.grakn.protocol.ThingType.UnsetOwns.ResH\x00R\x15thingTypeUnsetOwnsRes\x12\x61\n\x18thing_type_set_plays_res\x18\xb0\x02 \x01(\x0b\x32&.grakn.protocol.ThingType.SetPlays.ResH\x00R\x14thingTypeSetPlaysRes\x12g\n\x1athing_type_unset_plays_res\x18\xb1\x02 \x01(\x0b\x32(.grakn.protocol.ThingType.UnsetPlays.ResH\x00R\x16thingTypeUnsetPlaysRes\x12m\n\x1cthing_type_get_instances_res\x18\xb2\x02 \x01(\x0b\x32*.grakn.protocol.ThingType.GetInstances.ResH\x00R\x18thingTypeGetInstancesRes\x12^\n\x17thing_type_get_owns_res\x18\xb3\x02 \x01(\x0b\x32%.grakn.protocol.ThingType.GetOwns.ResH\x00R\x13thingTypeGetOwnsRes\x12\x61\n\x18thing_type_get_plays_res\x18\xb4\x02 \x01(\x0b\x32&.grakn.protocol.ThingType.GetPlays.ResH\x00R\x14thingTypeGetPlaysRes\x12]\n\x16\x65ntity_type_create_res\x18\x90\x03 \x01(\x0b\x32%.grakn.protocol.EntityType.Create.ResH\x00R\x13\x65ntityTypeCreateRes\x12\x63\n\x18relation_type_create_res\x18\xf4\x03 \x01(\x0b\x32\'.grakn.protocol.RelationType.Create.ResH\x00R\x15relationTypeCreateRes\x12\x97\x01\n,relation_type_get_relates_for_role_label_res\x18\xf5\x03 \x01(\x0b\x32\x37.grakn.protocol.RelationType.GetRelatesForRoleLabel.ResH\x00R%relationTypeGetRelatesForRoleLabelRes\x12p\n\x1drelation_type_set_relates_res\x18\xf6\x03 \x01(\x0b\x32+.grakn.protocol.RelationType.SetRelates.ResH\x00R\x19relationTypeSetRelatesRes\x12v\n\x1frelation_type_unset_relates_res\x18\xf7\x03 \x01(\x0b\x32-.grakn.protocol.RelationType.UnsetRelates.ResH\x00R\x1brelationTypeUnsetRelatesRes\x12p\n\x1drelation_type_get_relates_res\x18\xf8\x03 \x01(\x0b\x32+.grakn.protocol.RelationType.GetRelates.ResH\x00R\x19relationTypeGetRelatesRes\x12]\n\x16\x61ttribute_type_put_res\x18\xd8\x04 \x01(\x0b\x32%.grakn.protocol.AttributeType.Put.ResH\x00R\x13\x61ttributeTypePutRes\x12]\n\x16\x61ttribute_type_get_res\x18\xd9\x04 \x01(\x0b\x32%.grakn.protocol.AttributeType.Get.ResH\x00R\x13\x61ttributeTypeGetRes\x12m\n\x1c\x61ttribute_type_get_regex_res\x18\xda\x04 \x01(\x0b\x32*.grakn.protocol.AttributeType.GetRegex.ResH\x00R\x18\x61ttributeTypeGetRegexRes\x12m\n\x1c\x61ttribute_type_set_regex_res\x18\xdb\x04 \x01(\x0b\x32*.grakn.protocol.AttributeType.SetRegex.ResH\x00R\x18\x61ttributeTypeSetRegexRes\x12p\n\x1d\x61ttribute_type_get_owners_res\x18\xdc\x04 \x01(\x0b\x32+.grakn.protocol.AttributeType.GetOwners.ResH\x00R\x19\x61ttributeTypeGetOwnersResB\x05\n\x03res\x1a\x16\n\x06\x44\x65lete\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a.\n\x08SetLabel\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x05\n\x03Res\x1a\x36\n\nIsAbstract\x1a\x05\n\x03Req\x1a!\n\x03Res\x12\x1a\n\x08\x61\x62stract\x18\x01 \x01(\x08R\x08\x61\x62stract\x1aO\n\x0cGetSupertype\x1a\x05\n\x03Req\x1a\x38\n\x03Res\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\x04typeB\x05\n\x03res\x1a\x46\n\x0cSetSupertype\x1a/\n\x03Req\x12(\n\x04type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x04type\x1a\x05\n\x03Res\x1aI\n\rGetSupertypes\x1a\x05\n\x03Req\x1a\x31\n\x03Res\x12*\n\x05types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x05types\x1aG\n\x0bGetSubtypes\x1a\x05\n\x03Req\x1a\x31\n\x03Res\x12*\n\x05types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x05types\"a\n\x08\x45ncoding\x12\x0e\n\nTHING_TYPE\x10\x00\x12\x0f\n\x0b\x45NTITY_TYPE\x10\x01\x12\x11\n\rRELATION_TYPE\x10\x02\x12\x12\n\x0e\x41TTRIBUTE_TYPE\x10\x03\x12\r\n\tROLE_TYPE\x10\x04\"\x98\x02\n\x08RoleType\x1aZ\n\x0fGetRelationType\x1a\x05\n\x03Req\x1a@\n\x03Res\x12\x39\n\rrelation_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x0crelationType\x1a]\n\x10GetRelationTypes\x1a\x05\n\x03Req\x1a\x42\n\x03Res\x12;\n\x0erelation_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\rrelationTypes\x1aQ\n\nGetPlayers\x1a\x05\n\x03Req\x1a<\n\x03Res\x12\x35\n\x0bthing_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\nthingTypes\"\x94\x07\n\tThingType\x1a\x1b\n\x0bSetAbstract\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a\x1d\n\rUnsetAbstract\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1aK\n\x0cGetInstances\x1a\x05\n\x03Req\x1a\x34\n\x03Res\x12-\n\x06things\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\x06things\x1a\xc7\x01\n\x07GetOwns\x1av\n\x03Req\x12H\n\nvalue_type\x18\x01 \x01(\x0e\x32\'.grakn.protocol.AttributeType.ValueTypeH\x00R\tvalueType\x12\x1b\n\tkeys_only\x18\x03 \x01(\x08R\x08keysOnlyB\x08\n\x06\x66ilter\x1a\x44\n\x03Res\x12=\n\x0f\x61ttribute_types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x0e\x61ttributeTypes\x1a\x44\n\x08GetPlays\x1a\x05\n\x03Req\x1a\x31\n\x03Res\x12*\n\x05roles\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x05roles\x1a\xbb\x01\n\x07SetOwns\x1a\xa8\x01\n\x03Req\x12;\n\x0e\x61ttribute_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\rattributeType\x12?\n\x0foverridden_type\x18\x02 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\x0eoverriddenType\x12\x15\n\x06is_key\x18\x03 \x01(\x08R\x05isKeyB\x0c\n\noverridden\x1a\x05\n\x03Res\x1a\x91\x01\n\x08SetPlays\x1a~\n\x03Req\x12(\n\x04role\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x04role\x12?\n\x0foverridden_role\x18\x02 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\x0eoverriddenRoleB\x0c\n\noverridden\x1a\x05\n\x03Res\x1aV\n\tUnsetOwns\x1a\x42\n\x03Req\x12;\n\x0e\x61ttribute_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\rattributeType\x1a\x05\n\x03Res\x1a\x44\n\nUnsetPlays\x1a/\n\x03Req\x12(\n\x04role\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeR\x04role\x1a\x05\n\x03Res\"S\n\nEntityType\x1a\x45\n\x06\x43reate\x1a\x05\n\x03Req\x1a\x34\n\x03Res\x12-\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingR\x06\x65ntity\"\xbd\x03\n\x0cRelationType\x1aI\n\x06\x43reate\x1a\x05\n\x03Req\x1a\x38\n\x03Res\x12\x31\n\x08relation\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingR\x08relation\x1a\x46\n\nGetRelates\x1a\x05\n\x03Req\x1a\x31\n\x03Res\x12*\n\x05roles\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x05roles\x1ay\n\x16GetRelatesForRoleLabel\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x42\n\x03Res\x12\x33\n\trole_type\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.TypeH\x00R\x08roleTypeB\x06\n\x04role\x1ak\n\nSetRelates\x1aV\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12+\n\x10overridden_label\x18\x02 \x01(\tH\x00R\x0foverriddenLabelB\x0c\n\noverridden\x1a\x05\n\x03Res\x1a\x32\n\x0cUnsetRelates\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x05\n\x03Res\"\xef\x06\n\rAttributeType\x1a\x7f\n\x03Put\x1a<\n\x03Req\x12\x35\n\x05value\x18\x01 \x01(\x0b\x32\x1f.grakn.protocol.Attribute.ValueR\x05value\x1a:\n\x03Res\x12\x33\n\tattribute\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingR\tattribute\x1a\x88\x01\n\x03Get\x1a<\n\x03Req\x12\x35\n\x05value\x18\x01 \x01(\x0b\x32\x1f.grakn.protocol.Attribute.ValueR\x05value\x1a\x43\n\x03Res\x12\x35\n\tattribute\x18\x01 \x01(\x0b\x32\x15.grakn.protocol.ThingH\x00R\tattributeB\x05\n\x03res\x1a\x62\n\tGetOwners\x1a \n\x03Req\x12\x19\n\x08only_key\x18\x01 \x01(\x08R\x07onlyKey\x1a\x33\n\x03Res\x12,\n\x06owners\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x06owners\x1a.\n\x08GetRegex\x1a\x05\n\x03Req\x1a\x1b\n\x03Res\x12\x14\n\x05regex\x18\x01 \x01(\tR\x05regex\x1a.\n\x08SetRegex\x1a\x1b\n\x03Req\x12\x14\n\x05regex\x18\x01 \x01(\tR\x05regex\x1a\x05\n\x03Res\x1a\x98\x01\n\x0bGetSubtypes\x1aV\n\x03Req\x12H\n\nvalue_type\x18\x01 \x01(\x0e\x32\'.grakn.protocol.AttributeType.ValueTypeH\x00R\tvalueTypeB\x05\n\x03req\x1a\x31\n\x03Res\x12*\n\x05types\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.TypeR\x05types\x1a\x9c\x01\n\x0cGetInstances\x1aV\n\x03Req\x12H\n\nvalue_type\x18\x01 \x01(\x0e\x32\'.grakn.protocol.AttributeType.ValueTypeH\x00R\tvalueTypeB\x05\n\x03req\x1a\x34\n\x03Res\x12-\n\x06things\x18\x01 \x03(\x0b\x32\x15.grakn.protocol.ThingR\x06things\"T\n\tValueType\x12\n\n\x06OBJECT\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\x08\n\x04LONG\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05\x42\x1e\n\x0egrakn.protocolB\x0c\x43onceptProtob\x06proto3')
)



_TYPE_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='grakn.protocol.Type.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THING_TYPE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENTITY_TYPE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELATION_TYPE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTRIBUTE_TYPE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROLE_TYPE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13040,
  serialized_end=13137,
)
_sym_db.RegisterEnumDescriptor(_TYPE_ENCODING)

_ATTRIBUTETYPE_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='grakn.protocol.AttributeType.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBJECT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LONG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATETIME', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15670,
  serialized_end=15754,
)
_sym_db.RegisterEnumDescriptor(_ATTRIBUTETYPE_VALUETYPE)


_CONCEPTMANAGER_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_thing_type_req', full_name='grakn.protocol.ConceptManager.Req.get_thing_type_req', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getThingTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_thing_req', full_name='grakn.protocol.ConceptManager.Req.get_thing_req', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getThingReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_entity_type_req', full_name='grakn.protocol.ConceptManager.Req.put_entity_type_req', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putEntityTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_attribute_type_req', full_name='grakn.protocol.ConceptManager.Req.put_attribute_type_req', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putAttributeTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_relation_type_req', full_name='grakn.protocol.ConceptManager.Req.put_relation_type_req', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putRelationTypeReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.ConceptManager.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=62,
  serialized_end=565,
)

_CONCEPTMANAGER_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_thing_type_res', full_name='grakn.protocol.ConceptManager.Res.get_thing_type_res', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getThingTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_thing_res', full_name='grakn.protocol.ConceptManager.Res.get_thing_res', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getThingRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_entity_type_res', full_name='grakn.protocol.ConceptManager.Res.put_entity_type_res', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putEntityTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_attribute_type_res', full_name='grakn.protocol.ConceptManager.Res.put_attribute_type_res', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putAttributeTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_relation_type_res', full_name='grakn.protocol.ConceptManager.Res.put_relation_type_res', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putRelationTypeRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.ConceptManager.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=568,
  serialized_end=1071,
)

_CONCEPTMANAGER_GETTHINGTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.GetThingType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.ConceptManager.GetThingType.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_CONCEPTMANAGER_GETTHINGTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.GetThingType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing_type', full_name='grakn.protocol.ConceptManager.GetThingType.Res.thing_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.ConceptManager.GetThingType.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1118,
  serialized_end=1185,
)

_CONCEPTMANAGER_GETTHINGTYPE = _descriptor.Descriptor(
  name='GetThingType',
  full_name='grakn.protocol.ConceptManager.GetThingType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_GETTHINGTYPE_REQ, _CONCEPTMANAGER_GETTHINGTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1185,
)

_CONCEPTMANAGER_GETTHING_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.GetThing.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iid', full_name='grakn.protocol.ConceptManager.GetThing.Req.iid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='iid', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1222,
)

_CONCEPTMANAGER_GETTHING_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.GetThing.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing', full_name='grakn.protocol.ConceptManager.GetThing.Res.thing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thing', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.ConceptManager.GetThing.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1224,
  serialized_end=1283,
)

_CONCEPTMANAGER_GETTHING = _descriptor.Descriptor(
  name='GetThing',
  full_name='grakn.protocol.ConceptManager.GetThing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_GETTHING_REQ, _CONCEPTMANAGER_GETTHING_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1283,
)

_CONCEPTMANAGER_PUTENTITYTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.PutEntityType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.ConceptManager.PutEntityType.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_CONCEPTMANAGER_PUTENTITYTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.PutEntityType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_type', full_name='grakn.protocol.ConceptManager.PutEntityType.Res.entity_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1331,
  serialized_end=1391,
)

_CONCEPTMANAGER_PUTENTITYTYPE = _descriptor.Descriptor(
  name='PutEntityType',
  full_name='grakn.protocol.ConceptManager.PutEntityType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_PUTENTITYTYPE_REQ, _CONCEPTMANAGER_PUTENTITYTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1285,
  serialized_end=1391,
)

_CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.PutAttributeType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.ConceptManager.PutAttributeType.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='grakn.protocol.ConceptManager.PutAttributeType.Req.value_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valueType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1414,
  serialized_end=1513,
)

_CONCEPTMANAGER_PUTATTRIBUTETYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.PutAttributeType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_type', full_name='grakn.protocol.ConceptManager.PutAttributeType.Res.attribute_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1581,
)

_CONCEPTMANAGER_PUTATTRIBUTETYPE = _descriptor.Descriptor(
  name='PutAttributeType',
  full_name='grakn.protocol.ConceptManager.PutAttributeType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ, _CONCEPTMANAGER_PUTATTRIBUTETYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1581,
)

_CONCEPTMANAGER_PUTRELATIONTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ConceptManager.PutRelationType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.ConceptManager.PutRelationType.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_CONCEPTMANAGER_PUTRELATIONTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ConceptManager.PutRelationType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relation_type', full_name='grakn.protocol.ConceptManager.PutRelationType.Res.relation_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1695,
)

_CONCEPTMANAGER_PUTRELATIONTYPE = _descriptor.Descriptor(
  name='PutRelationType',
  full_name='grakn.protocol.ConceptManager.PutRelationType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_PUTRELATIONTYPE_REQ, _CONCEPTMANAGER_PUTRELATIONTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1695,
)

_CONCEPTMANAGER = _descriptor.Descriptor(
  name='ConceptManager',
  full_name='grakn.protocol.ConceptManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMANAGER_REQ, _CONCEPTMANAGER_RES, _CONCEPTMANAGER_GETTHINGTYPE, _CONCEPTMANAGER_GETTHING, _CONCEPTMANAGER_PUTENTITYTYPE, _CONCEPTMANAGER_PUTATTRIBUTETYPE, _CONCEPTMANAGER_PUTRELATIONTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=1695,
)


_CONCEPT = _descriptor.Descriptor(
  name='Concept',
  full_name='grakn.protocol.Concept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing', full_name='grakn.protocol.Concept.thing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thing', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Concept.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='concept', full_name='grakn.protocol.Concept.concept',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1697,
  serialized_end=1808,
)


_THING_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iid', full_name='grakn.protocol.Thing.Req.iid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='iid', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_delete_req', full_name='grakn.protocol.Thing.Req.thing_delete_req', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingDeleteReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_type_req', full_name='grakn.protocol.Thing.Req.thing_get_type_req', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_is_inferred_req', full_name='grakn.protocol.Thing.Req.thing_is_inferred_req', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingIsInferredReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_set_has_req', full_name='grakn.protocol.Thing.Req.thing_set_has_req', index=4,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingSetHasReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_unset_has_req', full_name='grakn.protocol.Thing.Req.thing_unset_has_req', index=5,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingUnsetHasReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_has_req', full_name='grakn.protocol.Thing.Req.thing_get_has_req', index=6,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetHasReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_relations_req', full_name='grakn.protocol.Thing.Req.thing_get_relations_req', index=7,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetRelationsReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_plays_req', full_name='grakn.protocol.Thing.Req.thing_get_plays_req', index=8,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetPlaysReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_add_player_req', full_name='grakn.protocol.Thing.Req.relation_add_player_req', index=9,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationAddPlayerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_remove_player_req', full_name='grakn.protocol.Thing.Req.relation_remove_player_req', index=10,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationRemovePlayerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_get_players_req', full_name='grakn.protocol.Thing.Req.relation_get_players_req', index=11,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationGetPlayersReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_get_players_by_role_type_req', full_name='grakn.protocol.Thing.Req.relation_get_players_by_role_type_req', index=12,
      number=203, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationGetPlayersByRoleTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_get_owners_req', full_name='grakn.protocol.Thing.Req.attribute_get_owners_req', index=13,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeGetOwnersReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Thing.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1936,
  serialized_end=3184,
)

_THING_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing_delete_res', full_name='grakn.protocol.Thing.Res.thing_delete_res', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingDeleteRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_type_res', full_name='grakn.protocol.Thing.Res.thing_get_type_res', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_is_inferred_res', full_name='grakn.protocol.Thing.Res.thing_is_inferred_res', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingIsInferredRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_set_has_res', full_name='grakn.protocol.Thing.Res.thing_set_has_res', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingSetHasRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_unset_has_res', full_name='grakn.protocol.Thing.Res.thing_unset_has_res', index=4,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingUnsetHasRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_has_res', full_name='grakn.protocol.Thing.Res.thing_get_has_res', index=5,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetHasRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_relations_res', full_name='grakn.protocol.Thing.Res.thing_get_relations_res', index=6,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetRelationsRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_get_plays_res', full_name='grakn.protocol.Thing.Res.thing_get_plays_res', index=7,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingGetPlaysRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_add_player_res', full_name='grakn.protocol.Thing.Res.relation_add_player_res', index=8,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationAddPlayerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_remove_player_res', full_name='grakn.protocol.Thing.Res.relation_remove_player_res', index=9,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationRemovePlayerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_get_players_res', full_name='grakn.protocol.Thing.Res.relation_get_players_res', index=10,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationGetPlayersRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_get_players_by_role_type_res', full_name='grakn.protocol.Thing.Res.relation_get_players_by_role_type_res', index=11,
      number=203, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationGetPlayersByRoleTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_get_owners_res', full_name='grakn.protocol.Thing.Res.attribute_get_owners_res', index=12,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeGetOwnersRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Thing.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3187,
  serialized_end=4417,
)

_THING_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THING_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THING_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Thing.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_DELETE_REQ, _THING_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4419,
  serialized_end=4441,
)

_THING_ISINFERRED_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.IsInferred.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THING_ISINFERRED_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.IsInferred.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inferred', full_name='grakn.protocol.Thing.IsInferred.Res.inferred', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inferred', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4464,
  serialized_end=4497,
)

_THING_ISINFERRED = _descriptor.Descriptor(
  name='IsInferred',
  full_name='grakn.protocol.Thing.IsInferred',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_ISINFERRED_REQ, _THING_ISINFERRED_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4443,
  serialized_end=4497,
)

_THING_GETTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.GetType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THING_GETTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.GetType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing_type', full_name='grakn.protocol.Thing.GetType.Res.thing_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4517,
  serialized_end=4575,
)

_THING_GETTYPE = _descriptor.Descriptor(
  name='GetType',
  full_name='grakn.protocol.Thing.GetType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_GETTYPE_REQ, _THING_GETTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4499,
  serialized_end=4575,
)

_THING_SETHAS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.SetHas.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='grakn.protocol.Thing.SetHas.Req.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attribute', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4587,
  serialized_end=4645,
)

_THING_SETHAS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.SetHas.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THING_SETHAS = _descriptor.Descriptor(
  name='SetHas',
  full_name='grakn.protocol.Thing.SetHas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_SETHAS_REQ, _THING_SETHAS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4577,
  serialized_end=4652,
)

_THING_UNSETHAS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.UnsetHas.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='grakn.protocol.Thing.UnsetHas.Req.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attribute', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4587,
  serialized_end=4645,
)

_THING_UNSETHAS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.UnsetHas.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THING_UNSETHAS = _descriptor.Descriptor(
  name='UnsetHas',
  full_name='grakn.protocol.Thing.UnsetHas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_UNSETHAS_REQ, _THING_UNSETHAS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4654,
  serialized_end=4731,
)

_THING_GETHAS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.GetHas.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_types', full_name='grakn.protocol.Thing.GetHas.Req.attribute_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys_only', full_name='grakn.protocol.Thing.GetHas.Req.keys_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='keysOnly', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4744,
  serialized_end=4841,
)

_THING_GETHAS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.GetHas.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grakn.protocol.Thing.GetHas.Res.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4843,
  serialized_end=4903,
)

_THING_GETHAS = _descriptor.Descriptor(
  name='GetHas',
  full_name='grakn.protocol.Thing.GetHas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_GETHAS_REQ, _THING_GETHAS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4734,
  serialized_end=4903,
)

_THING_GETPLAYS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.GetPlays.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THING_GETPLAYS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.GetPlays.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_types', full_name='grakn.protocol.Thing.GetPlays.Res.role_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4924,
  serialized_end=4982,
)

_THING_GETPLAYS = _descriptor.Descriptor(
  name='GetPlays',
  full_name='grakn.protocol.Thing.GetPlays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_GETPLAYS_REQ, _THING_GETPLAYS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4905,
  serialized_end=4982,
)

_THING_GETRELATIONS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Thing.GetRelations.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_types', full_name='grakn.protocol.Thing.GetRelations.Req.role_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5001,
  serialized_end=5059,
)

_THING_GETRELATIONS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Thing.GetRelations.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relations', full_name='grakn.protocol.Thing.GetRelations.Res.relations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relations', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5061,
  serialized_end=5119,
)

_THING_GETRELATIONS = _descriptor.Descriptor(
  name='GetRelations',
  full_name='grakn.protocol.Thing.GetRelations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THING_GETRELATIONS_REQ, _THING_GETRELATIONS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4985,
  serialized_end=5119,
)

_THING = _descriptor.Descriptor(
  name='Thing',
  full_name='grakn.protocol.Thing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iid', full_name='grakn.protocol.Thing.iid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='iid', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Thing.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.Thing.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_THING_REQ, _THING_RES, _THING_DELETE, _THING_ISINFERRED, _THING_GETTYPE, _THING_SETHAS, _THING_UNSETHAS, _THING_GETHAS, _THING_GETPLAYS, _THING_GETRELATIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=5119,
)


_RELATION_GETPLAYERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Relation.GetPlayers.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_types', full_name='grakn.protocol.Relation.GetPlayers.Req.role_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5001,
  serialized_end=5059,
)

_RELATION_GETPLAYERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Relation.GetPlayers.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='things', full_name='grakn.protocol.Relation.GetPlayers.Res.things', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='things', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5208,
  serialized_end=5260,
)

_RELATION_GETPLAYERS = _descriptor.Descriptor(
  name='GetPlayers',
  full_name='grakn.protocol.Relation.GetPlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATION_GETPLAYERS_REQ, _RELATION_GETPLAYERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5134,
  serialized_end=5260,
)

_RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER = _descriptor.Descriptor(
  name='RoleTypeWithPlayer',
  full_name='grakn.protocol.Relation.GetPlayersByRoleType.RoleTypeWithPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_type', full_name='grakn.protocol.Relation.GetPlayersByRoleType.RoleTypeWithPlayer.role_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player', full_name='grakn.protocol.Relation.GetPlayersByRoleType.RoleTypeWithPlayer.player', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='player', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5287,
  serialized_end=5405,
)

_RELATION_GETPLAYERSBYROLETYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Relation.GetPlayersByRoleType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_RELATION_GETPLAYERSBYROLETYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Relation.GetPlayersByRoleType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_types_with_players', full_name='grakn.protocol.Relation.GetPlayersByRoleType.Res.role_types_with_players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypesWithPlayers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5414,
  serialized_end=5540,
)

_RELATION_GETPLAYERSBYROLETYPE = _descriptor.Descriptor(
  name='GetPlayersByRoleType',
  full_name='grakn.protocol.Relation.GetPlayersByRoleType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER, _RELATION_GETPLAYERSBYROLETYPE_REQ, _RELATION_GETPLAYERSBYROLETYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5263,
  serialized_end=5540,
)

_RELATION_ADDPLAYER_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Relation.AddPlayer.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_type', full_name='grakn.protocol.Relation.AddPlayer.Req.role_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player', full_name='grakn.protocol.Relation.AddPlayer.Req.player', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='player', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5658,
)

_RELATION_ADDPLAYER_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Relation.AddPlayer.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_RELATION_ADDPLAYER = _descriptor.Descriptor(
  name='AddPlayer',
  full_name='grakn.protocol.Relation.AddPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATION_ADDPLAYER_REQ, _RELATION_ADDPLAYER_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5542,
  serialized_end=5665,
)

_RELATION_REMOVEPLAYER_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Relation.RemovePlayer.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_type', full_name='grakn.protocol.Relation.RemovePlayer.Req.role_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player', full_name='grakn.protocol.Relation.RemovePlayer.Req.player', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='player', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5658,
)

_RELATION_REMOVEPLAYER_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Relation.RemovePlayer.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_RELATION_REMOVEPLAYER = _descriptor.Descriptor(
  name='RemovePlayer',
  full_name='grakn.protocol.Relation.RemovePlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATION_REMOVEPLAYER_REQ, _RELATION_REMOVEPLAYER_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5667,
  serialized_end=5793,
)

_RELATION = _descriptor.Descriptor(
  name='Relation',
  full_name='grakn.protocol.Relation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATION_GETPLAYERS, _RELATION_GETPLAYERSBYROLETYPE, _RELATION_ADDPLAYER, _RELATION_REMOVEPLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5122,
  serialized_end=5793,
)


_ATTRIBUTE_GETOWNERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Attribute.GetOwners.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing_type', full_name='grakn.protocol.Attribute.GetOwners.Req.thing_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter', full_name='grakn.protocol.Attribute.GetOwners.Req.filter',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5823,
  serialized_end=5893,
)

_ATTRIBUTE_GETOWNERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Attribute.GetOwners.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='things', full_name='grakn.protocol.Attribute.GetOwners.Res.things', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='things', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5208,
  serialized_end=5260,
)

_ATTRIBUTE_GETOWNERS = _descriptor.Descriptor(
  name='GetOwners',
  full_name='grakn.protocol.Attribute.GetOwners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTE_GETOWNERS_REQ, _ATTRIBUTE_GETOWNERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5810,
  serialized_end=5947,
)

_ATTRIBUTE_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='grakn.protocol.Attribute.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string', full_name='grakn.protocol.Attribute.Value.string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='string', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='grakn.protocol.Attribute.Value.boolean', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='boolean', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long', full_name='grakn.protocol.Attribute.Value.long', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='long', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double', full_name='grakn.protocol.Attribute.Value.double', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='double', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_time', full_name='grakn.protocol.Attribute.Value.date_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dateTime', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='grakn.protocol.Attribute.Value.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5950,
  serialized_end=6099,
)

_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='grakn.protocol.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTE_GETOWNERS, _ATTRIBUTE_VALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5796,
  serialized_end=6099,
)


_TYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Type.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='grakn.protocol.Type.Req.scope', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scope', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_delete_req', full_name='grakn.protocol.Type.Req.type_delete_req', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeDeleteReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_set_label_req', full_name='grakn.protocol.Type.Req.type_set_label_req', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeSetLabelReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_is_abstract_req', full_name='grakn.protocol.Type.Req.type_is_abstract_req', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeIsAbstractReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_supertype_req', full_name='grakn.protocol.Type.Req.type_get_supertype_req', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSupertypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_set_supertype_req', full_name='grakn.protocol.Type.Req.type_set_supertype_req', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeSetSupertypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_supertypes_req', full_name='grakn.protocol.Type.Req.type_get_supertypes_req', index=7,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSupertypesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_subtypes_req', full_name='grakn.protocol.Type.Req.type_get_subtypes_req', index=8,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSubtypesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_relation_type_req', full_name='grakn.protocol.Type.Req.role_type_get_relation_type_req', index=9,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetRelationTypeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_relation_types_req', full_name='grakn.protocol.Type.Req.role_type_get_relation_types_req', index=10,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetRelationTypesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_players_req', full_name='grakn.protocol.Type.Req.role_type_get_players_req', index=11,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetPlayersReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_abstract_req', full_name='grakn.protocol.Type.Req.thing_type_set_abstract_req', index=12,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetAbstractReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_abstract_req', full_name='grakn.protocol.Type.Req.thing_type_unset_abstract_req', index=13,
      number=301, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetAbstractReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_owns_req', full_name='grakn.protocol.Type.Req.thing_type_set_owns_req', index=14,
      number=302, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetOwnsReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_owns_req', full_name='grakn.protocol.Type.Req.thing_type_unset_owns_req', index=15,
      number=303, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetOwnsReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_plays_req', full_name='grakn.protocol.Type.Req.thing_type_set_plays_req', index=16,
      number=304, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetPlaysReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_plays_req', full_name='grakn.protocol.Type.Req.thing_type_unset_plays_req', index=17,
      number=305, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetPlaysReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_instances_req', full_name='grakn.protocol.Type.Req.thing_type_get_instances_req', index=18,
      number=306, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetInstancesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_owns_req', full_name='grakn.protocol.Type.Req.thing_type_get_owns_req', index=19,
      number=307, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetOwnsReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_plays_req', full_name='grakn.protocol.Type.Req.thing_type_get_plays_req', index=20,
      number=308, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetPlaysReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_type_create_req', full_name='grakn.protocol.Type.Req.entity_type_create_req', index=21,
      number=400, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityTypeCreateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_create_req', full_name='grakn.protocol.Type.Req.relation_type_create_req', index=22,
      number=500, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeCreateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_get_relates_for_role_label_req', full_name='grakn.protocol.Type.Req.relation_type_get_relates_for_role_label_req', index=23,
      number=501, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeGetRelatesForRoleLabelReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_set_relates_req', full_name='grakn.protocol.Type.Req.relation_type_set_relates_req', index=24,
      number=502, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeSetRelatesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_unset_relates_req', full_name='grakn.protocol.Type.Req.relation_type_unset_relates_req', index=25,
      number=503, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeUnsetRelatesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_get_relates_req', full_name='grakn.protocol.Type.Req.relation_type_get_relates_req', index=26,
      number=504, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeGetRelatesReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_put_req', full_name='grakn.protocol.Type.Req.attribute_type_put_req', index=27,
      number=600, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypePutReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_req', full_name='grakn.protocol.Type.Req.attribute_type_get_req', index=28,
      number=601, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_regex_req', full_name='grakn.protocol.Type.Req.attribute_type_get_regex_req', index=29,
      number=602, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetRegexReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_set_regex_req', full_name='grakn.protocol.Type.Req.attribute_type_set_regex_req', index=30,
      number=603, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeSetRegexReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_owners_req', full_name='grakn.protocol.Type.Req.attribute_type_get_owners_req', index=31,
      number=604, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetOwnersReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Type.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6306,
  serialized_end=9478,
)

_TYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_delete_res', full_name='grakn.protocol.Type.Res.type_delete_res', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeDeleteRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_set_label_res', full_name='grakn.protocol.Type.Res.type_set_label_res', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeSetLabelRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_is_abstract_res', full_name='grakn.protocol.Type.Res.type_is_abstract_res', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeIsAbstractRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_supertype_res', full_name='grakn.protocol.Type.Res.type_get_supertype_res', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSupertypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_set_supertype_res', full_name='grakn.protocol.Type.Res.type_set_supertype_res', index=4,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeSetSupertypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_supertypes_res', full_name='grakn.protocol.Type.Res.type_get_supertypes_res', index=5,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSupertypesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_get_subtypes_res', full_name='grakn.protocol.Type.Res.type_get_subtypes_res', index=6,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeGetSubtypesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_relation_type_res', full_name='grakn.protocol.Type.Res.role_type_get_relation_type_res', index=7,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetRelationTypeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_relation_types_res', full_name='grakn.protocol.Type.Res.role_type_get_relation_types_res', index=8,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetRelationTypesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_type_get_players_res', full_name='grakn.protocol.Type.Res.role_type_get_players_res', index=9,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleTypeGetPlayersRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_abstract_res', full_name='grakn.protocol.Type.Res.thing_type_set_abstract_res', index=10,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetAbstractRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_abstract_res', full_name='grakn.protocol.Type.Res.thing_type_unset_abstract_res', index=11,
      number=301, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetAbstractRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_owns_res', full_name='grakn.protocol.Type.Res.thing_type_set_owns_res', index=12,
      number=302, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetOwnsRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_owns_res', full_name='grakn.protocol.Type.Res.thing_type_unset_owns_res', index=13,
      number=303, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetOwnsRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_set_plays_res', full_name='grakn.protocol.Type.Res.thing_type_set_plays_res', index=14,
      number=304, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeSetPlaysRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_unset_plays_res', full_name='grakn.protocol.Type.Res.thing_type_unset_plays_res', index=15,
      number=305, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeUnsetPlaysRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_instances_res', full_name='grakn.protocol.Type.Res.thing_type_get_instances_res', index=16,
      number=306, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetInstancesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_owns_res', full_name='grakn.protocol.Type.Res.thing_type_get_owns_res', index=17,
      number=307, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetOwnsRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_type_get_plays_res', full_name='grakn.protocol.Type.Res.thing_type_get_plays_res', index=18,
      number=308, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypeGetPlaysRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_type_create_res', full_name='grakn.protocol.Type.Res.entity_type_create_res', index=19,
      number=400, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityTypeCreateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_create_res', full_name='grakn.protocol.Type.Res.relation_type_create_res', index=20,
      number=500, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeCreateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_get_relates_for_role_label_res', full_name='grakn.protocol.Type.Res.relation_type_get_relates_for_role_label_res', index=21,
      number=501, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeGetRelatesForRoleLabelRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_set_relates_res', full_name='grakn.protocol.Type.Res.relation_type_set_relates_res', index=22,
      number=502, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeSetRelatesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_unset_relates_res', full_name='grakn.protocol.Type.Res.relation_type_unset_relates_res', index=23,
      number=503, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeUnsetRelatesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relation_type_get_relates_res', full_name='grakn.protocol.Type.Res.relation_type_get_relates_res', index=24,
      number=504, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypeGetRelatesRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_put_res', full_name='grakn.protocol.Type.Res.attribute_type_put_res', index=25,
      number=600, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypePutRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_res', full_name='grakn.protocol.Type.Res.attribute_type_get_res', index=26,
      number=601, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_regex_res', full_name='grakn.protocol.Type.Res.attribute_type_get_regex_res', index=27,
      number=602, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetRegexRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_set_regex_res', full_name='grakn.protocol.Type.Res.attribute_type_set_regex_res', index=28,
      number=603, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeSetRegexRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_type_get_owners_res', full_name='grakn.protocol.Type.Res.attribute_type_get_owners_res', index=29,
      number=604, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypeGetOwnersRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Type.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=9481,
  serialized_end=12609,
)

_TYPE_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_TYPE_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_TYPE_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Type.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_DELETE_REQ, _TYPE_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4419,
  serialized_end=4441,
)

_TYPE_SETLABEL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.SetLabel.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Type.SetLabel.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_TYPE_SETLABEL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.SetLabel.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_TYPE_SETLABEL = _descriptor.Descriptor(
  name='SetLabel',
  full_name='grakn.protocol.Type.SetLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_SETLABEL_REQ, _TYPE_SETLABEL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12635,
  serialized_end=12681,
)

_TYPE_ISABSTRACT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.IsAbstract.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_TYPE_ISABSTRACT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.IsAbstract.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='abstract', full_name='grakn.protocol.Type.IsAbstract.Res.abstract', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='abstract', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12704,
  serialized_end=12737,
)

_TYPE_ISABSTRACT = _descriptor.Descriptor(
  name='IsAbstract',
  full_name='grakn.protocol.Type.IsAbstract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_ISABSTRACT_REQ, _TYPE_ISABSTRACT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12683,
  serialized_end=12737,
)

_TYPE_GETSUPERTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.GetSupertype.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_TYPE_GETSUPERTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.GetSupertype.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Type.GetSupertype.Res.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Type.GetSupertype.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=12762,
  serialized_end=12818,
)

_TYPE_GETSUPERTYPE = _descriptor.Descriptor(
  name='GetSupertype',
  full_name='grakn.protocol.Type.GetSupertype',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_GETSUPERTYPE_REQ, _TYPE_GETSUPERTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12739,
  serialized_end=12818,
)

_TYPE_SETSUPERTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.SetSupertype.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Type.SetSupertype.Req.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12836,
  serialized_end=12883,
)

_TYPE_SETSUPERTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.SetSupertype.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_TYPE_SETSUPERTYPE = _descriptor.Descriptor(
  name='SetSupertype',
  full_name='grakn.protocol.Type.SetSupertype',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_SETSUPERTYPE_REQ, _TYPE_SETSUPERTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12820,
  serialized_end=12890,
)

_TYPE_GETSUPERTYPES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.GetSupertypes.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_TYPE_GETSUPERTYPES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.GetSupertypes.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='grakn.protocol.Type.GetSupertypes.Res.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='types', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12916,
  serialized_end=12965,
)

_TYPE_GETSUPERTYPES = _descriptor.Descriptor(
  name='GetSupertypes',
  full_name='grakn.protocol.Type.GetSupertypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_GETSUPERTYPES_REQ, _TYPE_GETSUPERTYPES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12892,
  serialized_end=12965,
)

_TYPE_GETSUBTYPES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Type.GetSubtypes.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_TYPE_GETSUBTYPES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Type.GetSubtypes.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='grakn.protocol.Type.GetSubtypes.Res.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='types', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12916,
  serialized_end=12965,
)

_TYPE_GETSUBTYPES = _descriptor.Descriptor(
  name='GetSubtypes',
  full_name='grakn.protocol.Type.GetSubtypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPE_GETSUBTYPES_REQ, _TYPE_GETSUBTYPES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12967,
  serialized_end=13038,
)

_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='grakn.protocol.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Type.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='grakn.protocol.Type.scope', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scope', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='grakn.protocol.Type.encoding', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encoding', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='grakn.protocol.Type.value_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valueType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='grakn.protocol.Type.root', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='root', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_REQ, _TYPE_RES, _TYPE_DELETE, _TYPE_SETLABEL, _TYPE_ISABSTRACT, _TYPE_GETSUPERTYPE, _TYPE_SETSUPERTYPE, _TYPE_GETSUPERTYPES, _TYPE_GETSUBTYPES, ],
  enum_types=[
    _TYPE_ENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6102,
  serialized_end=13137,
)


_ROLETYPE_GETRELATIONTYPE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RoleType.GetRelationType.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_ROLETYPE_GETRELATIONTYPE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RoleType.GetRelationType.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relation_type', full_name='grakn.protocol.RoleType.GetRelationType.Res.relation_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1695,
)

_ROLETYPE_GETRELATIONTYPE = _descriptor.Descriptor(
  name='GetRelationType',
  full_name='grakn.protocol.RoleType.GetRelationType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ROLETYPE_GETRELATIONTYPE_REQ, _ROLETYPE_GETRELATIONTYPE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13152,
  serialized_end=13242,
)

_ROLETYPE_GETRELATIONTYPES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RoleType.GetRelationTypes.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_ROLETYPE_GETRELATIONTYPES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RoleType.GetRelationTypes.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relation_types', full_name='grakn.protocol.RoleType.GetRelationTypes.Res.relation_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relationTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13271,
  serialized_end=13337,
)

_ROLETYPE_GETRELATIONTYPES = _descriptor.Descriptor(
  name='GetRelationTypes',
  full_name='grakn.protocol.RoleType.GetRelationTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ROLETYPE_GETRELATIONTYPES_REQ, _ROLETYPE_GETRELATIONTYPES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13244,
  serialized_end=13337,
)

_ROLETYPE_GETPLAYERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RoleType.GetPlayers.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_ROLETYPE_GETPLAYERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RoleType.GetPlayers.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='thing_types', full_name='grakn.protocol.RoleType.GetPlayers.Res.thing_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13360,
  serialized_end=13420,
)

_ROLETYPE_GETPLAYERS = _descriptor.Descriptor(
  name='GetPlayers',
  full_name='grakn.protocol.RoleType.GetPlayers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ROLETYPE_GETPLAYERS_REQ, _ROLETYPE_GETPLAYERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13339,
  serialized_end=13420,
)

_ROLETYPE = _descriptor.Descriptor(
  name='RoleType',
  full_name='grakn.protocol.RoleType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ROLETYPE_GETRELATIONTYPE, _ROLETYPE_GETRELATIONTYPES, _ROLETYPE_GETPLAYERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13140,
  serialized_end=13420,
)


_THINGTYPE_SETABSTRACT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.SetAbstract.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THINGTYPE_SETABSTRACT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.SetAbstract.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_SETABSTRACT = _descriptor.Descriptor(
  name='SetAbstract',
  full_name='grakn.protocol.ThingType.SetAbstract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_SETABSTRACT_REQ, _THINGTYPE_SETABSTRACT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13436,
  serialized_end=13463,
)

_THINGTYPE_UNSETABSTRACT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.UnsetAbstract.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THINGTYPE_UNSETABSTRACT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.UnsetAbstract.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_UNSETABSTRACT = _descriptor.Descriptor(
  name='UnsetAbstract',
  full_name='grakn.protocol.ThingType.UnsetAbstract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_UNSETABSTRACT_REQ, _THINGTYPE_UNSETABSTRACT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13465,
  serialized_end=13494,
)

_THINGTYPE_GETINSTANCES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.GetInstances.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THINGTYPE_GETINSTANCES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.GetInstances.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='things', full_name='grakn.protocol.ThingType.GetInstances.Res.things', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='things', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5208,
  serialized_end=5260,
)

_THINGTYPE_GETINSTANCES = _descriptor.Descriptor(
  name='GetInstances',
  full_name='grakn.protocol.ThingType.GetInstances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_GETINSTANCES_REQ, _THINGTYPE_GETINSTANCES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13496,
  serialized_end=13571,
)

_THINGTYPE_GETOWNS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.GetOwns.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_type', full_name='grakn.protocol.ThingType.GetOwns.Req.value_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valueType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys_only', full_name='grakn.protocol.ThingType.GetOwns.Req.keys_only', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='keysOnly', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter', full_name='grakn.protocol.ThingType.GetOwns.Req.filter',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=13585,
  serialized_end=13703,
)

_THINGTYPE_GETOWNS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.GetOwns.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_types', full_name='grakn.protocol.ThingType.GetOwns.Res.attribute_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeTypes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13705,
  serialized_end=13773,
)

_THINGTYPE_GETOWNS = _descriptor.Descriptor(
  name='GetOwns',
  full_name='grakn.protocol.ThingType.GetOwns',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_GETOWNS_REQ, _THINGTYPE_GETOWNS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13574,
  serialized_end=13773,
)

_THINGTYPE_GETPLAYS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.GetPlays.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_THINGTYPE_GETPLAYS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.GetPlays.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='grakn.protocol.ThingType.GetPlays.Res.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roles', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13794,
  serialized_end=13843,
)

_THINGTYPE_GETPLAYS = _descriptor.Descriptor(
  name='GetPlays',
  full_name='grakn.protocol.ThingType.GetPlays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_GETPLAYS_REQ, _THINGTYPE_GETPLAYS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13775,
  serialized_end=13843,
)

_THINGTYPE_SETOWNS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.SetOwns.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_type', full_name='grakn.protocol.ThingType.SetOwns.Req.attribute_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overridden_type', full_name='grakn.protocol.ThingType.SetOwns.Req.overridden_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overriddenType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_key', full_name='grakn.protocol.ThingType.SetOwns.Req.is_key', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isKey', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='overridden', full_name='grakn.protocol.ThingType.SetOwns.Req.overridden',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=13858,
  serialized_end=14026,
)

_THINGTYPE_SETOWNS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.SetOwns.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_SETOWNS = _descriptor.Descriptor(
  name='SetOwns',
  full_name='grakn.protocol.ThingType.SetOwns',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_SETOWNS_REQ, _THINGTYPE_SETOWNS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13846,
  serialized_end=14033,
)

_THINGTYPE_SETPLAYS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.SetPlays.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='grakn.protocol.ThingType.SetPlays.Req.role', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='role', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overridden_role', full_name='grakn.protocol.ThingType.SetPlays.Req.overridden_role', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overriddenRole', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='overridden', full_name='grakn.protocol.ThingType.SetPlays.Req.overridden',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=14048,
  serialized_end=14174,
)

_THINGTYPE_SETPLAYS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.SetPlays.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_SETPLAYS = _descriptor.Descriptor(
  name='SetPlays',
  full_name='grakn.protocol.ThingType.SetPlays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_SETPLAYS_REQ, _THINGTYPE_SETPLAYS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14036,
  serialized_end=14181,
)

_THINGTYPE_UNSETOWNS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.UnsetOwns.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_type', full_name='grakn.protocol.ThingType.UnsetOwns.Req.attribute_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributeType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13858,
  serialized_end=13924,
)

_THINGTYPE_UNSETOWNS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.UnsetOwns.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_UNSETOWNS = _descriptor.Descriptor(
  name='UnsetOwns',
  full_name='grakn.protocol.ThingType.UnsetOwns',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_UNSETOWNS_REQ, _THINGTYPE_UNSETOWNS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14183,
  serialized_end=14269,
)

_THINGTYPE_UNSETPLAYS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.ThingType.UnsetPlays.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='grakn.protocol.ThingType.UnsetPlays.Req.role', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='role', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14048,
  serialized_end=14095,
)

_THINGTYPE_UNSETPLAYS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.ThingType.UnsetPlays.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_THINGTYPE_UNSETPLAYS = _descriptor.Descriptor(
  name='UnsetPlays',
  full_name='grakn.protocol.ThingType.UnsetPlays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_UNSETPLAYS_REQ, _THINGTYPE_UNSETPLAYS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14271,
  serialized_end=14339,
)

_THINGTYPE = _descriptor.Descriptor(
  name='ThingType',
  full_name='grakn.protocol.ThingType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_THINGTYPE_SETABSTRACT, _THINGTYPE_UNSETABSTRACT, _THINGTYPE_GETINSTANCES, _THINGTYPE_GETOWNS, _THINGTYPE_GETPLAYS, _THINGTYPE_SETOWNS, _THINGTYPE_SETPLAYS, _THINGTYPE_UNSETOWNS, _THINGTYPE_UNSETPLAYS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13423,
  serialized_end=14339,
)


_ENTITYTYPE_CREATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.EntityType.Create.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_ENTITYTYPE_CREATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.EntityType.Create.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity', full_name='grakn.protocol.EntityType.Create.Res.entity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14372,
  serialized_end=14424,
)

_ENTITYTYPE_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='grakn.protocol.EntityType.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ENTITYTYPE_CREATE_REQ, _ENTITYTYPE_CREATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14355,
  serialized_end=14424,
)

_ENTITYTYPE = _descriptor.Descriptor(
  name='EntityType',
  full_name='grakn.protocol.EntityType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ENTITYTYPE_CREATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14341,
  serialized_end=14424,
)


_RELATIONTYPE_CREATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RelationType.Create.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_RELATIONTYPE_CREATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RelationType.Create.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relation', full_name='grakn.protocol.RelationType.Create.Res.relation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='relation', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14460,
  serialized_end=14516,
)

_RELATIONTYPE_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='grakn.protocol.RelationType.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_CREATE_REQ, _RELATIONTYPE_CREATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14443,
  serialized_end=14516,
)

_RELATIONTYPE_GETRELATES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RelationType.GetRelates.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_RELATIONTYPE_GETRELATES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RelationType.GetRelates.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='grakn.protocol.RelationType.GetRelates.Res.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roles', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13794,
  serialized_end=13843,
)

_RELATIONTYPE_GETRELATES = _descriptor.Descriptor(
  name='GetRelates',
  full_name='grakn.protocol.RelationType.GetRelates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_GETRELATES_REQ, _RELATIONTYPE_GETRELATES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14518,
  serialized_end=14588,
)

_RELATIONTYPE_GETRELATESFORROLELABEL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_RELATIONTYPE_GETRELATESFORROLELABEL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_type', full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel.Res.role_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='roleType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='role', full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel.Res.role',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=14645,
  serialized_end=14711,
)

_RELATIONTYPE_GETRELATESFORROLELABEL = _descriptor.Descriptor(
  name='GetRelatesForRoleLabel',
  full_name='grakn.protocol.RelationType.GetRelatesForRoleLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_GETRELATESFORROLELABEL_REQ, _RELATIONTYPE_GETRELATESFORROLELABEL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14590,
  serialized_end=14711,
)

_RELATIONTYPE_SETRELATES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RelationType.SetRelates.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.RelationType.SetRelates.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overridden_label', full_name='grakn.protocol.RelationType.SetRelates.Req.overridden_label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overriddenLabel', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='overridden', full_name='grakn.protocol.RelationType.SetRelates.Req.overridden',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=14727,
  serialized_end=14813,
)

_RELATIONTYPE_SETRELATES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RelationType.SetRelates.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_RELATIONTYPE_SETRELATES = _descriptor.Descriptor(
  name='SetRelates',
  full_name='grakn.protocol.RelationType.SetRelates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_SETRELATES_REQ, _RELATIONTYPE_SETRELATES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14713,
  serialized_end=14820,
)

_RELATIONTYPE_UNSETRELATES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.RelationType.UnsetRelates.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.RelationType.UnsetRelates.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1116,
)

_RELATIONTYPE_UNSETRELATES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.RelationType.UnsetRelates.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_RELATIONTYPE_UNSETRELATES = _descriptor.Descriptor(
  name='UnsetRelates',
  full_name='grakn.protocol.RelationType.UnsetRelates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_UNSETRELATES_REQ, _RELATIONTYPE_UNSETRELATES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14822,
  serialized_end=14872,
)

_RELATIONTYPE = _descriptor.Descriptor(
  name='RelationType',
  full_name='grakn.protocol.RelationType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RELATIONTYPE_CREATE, _RELATIONTYPE_GETRELATES, _RELATIONTYPE_GETRELATESFORROLELABEL, _RELATIONTYPE_SETRELATES, _RELATIONTYPE_UNSETRELATES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14427,
  serialized_end=14872,
)


_ATTRIBUTETYPE_PUT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.Put.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.AttributeType.Put.Req.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14899,
  serialized_end=14959,
)

_ATTRIBUTETYPE_PUT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.Put.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='grakn.protocol.AttributeType.Put.Res.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attribute', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14961,
  serialized_end=15019,
)

_ATTRIBUTETYPE_PUT = _descriptor.Descriptor(
  name='Put',
  full_name='grakn.protocol.AttributeType.Put',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_PUT_REQ, _ATTRIBUTETYPE_PUT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14892,
  serialized_end=15019,
)

_ATTRIBUTETYPE_GET_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.Get.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.AttributeType.Get.Req.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14899,
  serialized_end=14959,
)

_ATTRIBUTETYPE_GET_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.Get.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='grakn.protocol.AttributeType.Get.Res.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attribute', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.AttributeType.Get.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=15091,
  serialized_end=15158,
)

_ATTRIBUTETYPE_GET = _descriptor.Descriptor(
  name='Get',
  full_name='grakn.protocol.AttributeType.Get',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_GET_REQ, _ATTRIBUTETYPE_GET_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15022,
  serialized_end=15158,
)

_ATTRIBUTETYPE_GETOWNERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.GetOwners.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='only_key', full_name='grakn.protocol.AttributeType.GetOwners.Req.only_key', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlyKey', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15173,
  serialized_end=15205,
)

_ATTRIBUTETYPE_GETOWNERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.GetOwners.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owners', full_name='grakn.protocol.AttributeType.GetOwners.Res.owners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='owners', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15207,
  serialized_end=15258,
)

_ATTRIBUTETYPE_GETOWNERS = _descriptor.Descriptor(
  name='GetOwners',
  full_name='grakn.protocol.AttributeType.GetOwners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_GETOWNERS_REQ, _ATTRIBUTETYPE_GETOWNERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15160,
  serialized_end=15258,
)

_ATTRIBUTETYPE_GETREGEX_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.GetRegex.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=67,
)

_ATTRIBUTETYPE_GETREGEX_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.GetRegex.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regex', full_name='grakn.protocol.AttributeType.GetRegex.Res.regex', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='regex', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15279,
  serialized_end=15306,
)

_ATTRIBUTETYPE_GETREGEX = _descriptor.Descriptor(
  name='GetRegex',
  full_name='grakn.protocol.AttributeType.GetRegex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_GETREGEX_REQ, _ATTRIBUTETYPE_GETREGEX_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15260,
  serialized_end=15306,
)

_ATTRIBUTETYPE_SETREGEX_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.SetRegex.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regex', full_name='grakn.protocol.AttributeType.SetRegex.Req.regex', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='regex', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15320,
  serialized_end=15347,
)

_ATTRIBUTETYPE_SETREGEX_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.SetRegex.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=573,
)

_ATTRIBUTETYPE_SETREGEX = _descriptor.Descriptor(
  name='SetRegex',
  full_name='grakn.protocol.AttributeType.SetRegex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_SETREGEX_REQ, _ATTRIBUTETYPE_SETREGEX_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15308,
  serialized_end=15354,
)

_ATTRIBUTETYPE_GETSUBTYPES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.GetSubtypes.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_type', full_name='grakn.protocol.AttributeType.GetSubtypes.Req.value_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valueType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.AttributeType.GetSubtypes.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=15372,
  serialized_end=15458,
)

_ATTRIBUTETYPE_GETSUBTYPES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.GetSubtypes.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='grakn.protocol.AttributeType.GetSubtypes.Res.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='types', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12916,
  serialized_end=12965,
)

_ATTRIBUTETYPE_GETSUBTYPES = _descriptor.Descriptor(
  name='GetSubtypes',
  full_name='grakn.protocol.AttributeType.GetSubtypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_GETSUBTYPES_REQ, _ATTRIBUTETYPE_GETSUBTYPES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15357,
  serialized_end=15509,
)

_ATTRIBUTETYPE_GETINSTANCES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.AttributeType.GetInstances.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_type', full_name='grakn.protocol.AttributeType.GetInstances.Req.value_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valueType', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.AttributeType.GetInstances.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=15372,
  serialized_end=15458,
)

_ATTRIBUTETYPE_GETINSTANCES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.AttributeType.GetInstances.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='things', full_name='grakn.protocol.AttributeType.GetInstances.Res.things', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='things', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5208,
  serialized_end=5260,
)

_ATTRIBUTETYPE_GETINSTANCES = _descriptor.Descriptor(
  name='GetInstances',
  full_name='grakn.protocol.AttributeType.GetInstances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_GETINSTANCES_REQ, _ATTRIBUTETYPE_GETINSTANCES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15512,
  serialized_end=15668,
)

_ATTRIBUTETYPE = _descriptor.Descriptor(
  name='AttributeType',
  full_name='grakn.protocol.AttributeType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTETYPE_PUT, _ATTRIBUTETYPE_GET, _ATTRIBUTETYPE_GETOWNERS, _ATTRIBUTETYPE_GETREGEX, _ATTRIBUTETYPE_SETREGEX, _ATTRIBUTETYPE_GETSUBTYPES, _ATTRIBUTETYPE_GETINSTANCES, ],
  enum_types=[
    _ATTRIBUTETYPE_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14875,
  serialized_end=15754,
)

_CONCEPTMANAGER_REQ.fields_by_name['get_thing_type_req'].message_type = _CONCEPTMANAGER_GETTHINGTYPE_REQ
_CONCEPTMANAGER_REQ.fields_by_name['get_thing_req'].message_type = _CONCEPTMANAGER_GETTHING_REQ
_CONCEPTMANAGER_REQ.fields_by_name['put_entity_type_req'].message_type = _CONCEPTMANAGER_PUTENTITYTYPE_REQ
_CONCEPTMANAGER_REQ.fields_by_name['put_attribute_type_req'].message_type = _CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ
_CONCEPTMANAGER_REQ.fields_by_name['put_relation_type_req'].message_type = _CONCEPTMANAGER_PUTRELATIONTYPE_REQ
_CONCEPTMANAGER_REQ.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _CONCEPTMANAGER_REQ.fields_by_name['get_thing_type_req'])
_CONCEPTMANAGER_REQ.fields_by_name['get_thing_type_req'].containing_oneof = _CONCEPTMANAGER_REQ.oneofs_by_name['req']
_CONCEPTMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _CONCEPTMANAGER_REQ.fields_by_name['get_thing_req'])
_CONCEPTMANAGER_REQ.fields_by_name['get_thing_req'].containing_oneof = _CONCEPTMANAGER_REQ.oneofs_by_name['req']
_CONCEPTMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _CONCEPTMANAGER_REQ.fields_by_name['put_entity_type_req'])
_CONCEPTMANAGER_REQ.fields_by_name['put_entity_type_req'].containing_oneof = _CONCEPTMANAGER_REQ.oneofs_by_name['req']
_CONCEPTMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _CONCEPTMANAGER_REQ.fields_by_name['put_attribute_type_req'])
_CONCEPTMANAGER_REQ.fields_by_name['put_attribute_type_req'].containing_oneof = _CONCEPTMANAGER_REQ.oneofs_by_name['req']
_CONCEPTMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _CONCEPTMANAGER_REQ.fields_by_name['put_relation_type_req'])
_CONCEPTMANAGER_REQ.fields_by_name['put_relation_type_req'].containing_oneof = _CONCEPTMANAGER_REQ.oneofs_by_name['req']
_CONCEPTMANAGER_RES.fields_by_name['get_thing_type_res'].message_type = _CONCEPTMANAGER_GETTHINGTYPE_RES
_CONCEPTMANAGER_RES.fields_by_name['get_thing_res'].message_type = _CONCEPTMANAGER_GETTHING_RES
_CONCEPTMANAGER_RES.fields_by_name['put_entity_type_res'].message_type = _CONCEPTMANAGER_PUTENTITYTYPE_RES
_CONCEPTMANAGER_RES.fields_by_name['put_attribute_type_res'].message_type = _CONCEPTMANAGER_PUTATTRIBUTETYPE_RES
_CONCEPTMANAGER_RES.fields_by_name['put_relation_type_res'].message_type = _CONCEPTMANAGER_PUTRELATIONTYPE_RES
_CONCEPTMANAGER_RES.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_RES.fields_by_name['get_thing_type_res'])
_CONCEPTMANAGER_RES.fields_by_name['get_thing_type_res'].containing_oneof = _CONCEPTMANAGER_RES.oneofs_by_name['res']
_CONCEPTMANAGER_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_RES.fields_by_name['get_thing_res'])
_CONCEPTMANAGER_RES.fields_by_name['get_thing_res'].containing_oneof = _CONCEPTMANAGER_RES.oneofs_by_name['res']
_CONCEPTMANAGER_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_RES.fields_by_name['put_entity_type_res'])
_CONCEPTMANAGER_RES.fields_by_name['put_entity_type_res'].containing_oneof = _CONCEPTMANAGER_RES.oneofs_by_name['res']
_CONCEPTMANAGER_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_RES.fields_by_name['put_attribute_type_res'])
_CONCEPTMANAGER_RES.fields_by_name['put_attribute_type_res'].containing_oneof = _CONCEPTMANAGER_RES.oneofs_by_name['res']
_CONCEPTMANAGER_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_RES.fields_by_name['put_relation_type_res'])
_CONCEPTMANAGER_RES.fields_by_name['put_relation_type_res'].containing_oneof = _CONCEPTMANAGER_RES.oneofs_by_name['res']
_CONCEPTMANAGER_GETTHINGTYPE_REQ.containing_type = _CONCEPTMANAGER_GETTHINGTYPE
_CONCEPTMANAGER_GETTHINGTYPE_RES.fields_by_name['thing_type'].message_type = _TYPE
_CONCEPTMANAGER_GETTHINGTYPE_RES.containing_type = _CONCEPTMANAGER_GETTHINGTYPE
_CONCEPTMANAGER_GETTHINGTYPE_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_GETTHINGTYPE_RES.fields_by_name['thing_type'])
_CONCEPTMANAGER_GETTHINGTYPE_RES.fields_by_name['thing_type'].containing_oneof = _CONCEPTMANAGER_GETTHINGTYPE_RES.oneofs_by_name['res']
_CONCEPTMANAGER_GETTHINGTYPE.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_GETTHING_REQ.containing_type = _CONCEPTMANAGER_GETTHING
_CONCEPTMANAGER_GETTHING_RES.fields_by_name['thing'].message_type = _THING
_CONCEPTMANAGER_GETTHING_RES.containing_type = _CONCEPTMANAGER_GETTHING
_CONCEPTMANAGER_GETTHING_RES.oneofs_by_name['res'].fields.append(
  _CONCEPTMANAGER_GETTHING_RES.fields_by_name['thing'])
_CONCEPTMANAGER_GETTHING_RES.fields_by_name['thing'].containing_oneof = _CONCEPTMANAGER_GETTHING_RES.oneofs_by_name['res']
_CONCEPTMANAGER_GETTHING.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_PUTENTITYTYPE_REQ.containing_type = _CONCEPTMANAGER_PUTENTITYTYPE
_CONCEPTMANAGER_PUTENTITYTYPE_RES.fields_by_name['entity_type'].message_type = _TYPE
_CONCEPTMANAGER_PUTENTITYTYPE_RES.containing_type = _CONCEPTMANAGER_PUTENTITYTYPE
_CONCEPTMANAGER_PUTENTITYTYPE.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ.fields_by_name['value_type'].enum_type = _ATTRIBUTETYPE_VALUETYPE
_CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ.containing_type = _CONCEPTMANAGER_PUTATTRIBUTETYPE
_CONCEPTMANAGER_PUTATTRIBUTETYPE_RES.fields_by_name['attribute_type'].message_type = _TYPE
_CONCEPTMANAGER_PUTATTRIBUTETYPE_RES.containing_type = _CONCEPTMANAGER_PUTATTRIBUTETYPE
_CONCEPTMANAGER_PUTATTRIBUTETYPE.containing_type = _CONCEPTMANAGER
_CONCEPTMANAGER_PUTRELATIONTYPE_REQ.containing_type = _CONCEPTMANAGER_PUTRELATIONTYPE
_CONCEPTMANAGER_PUTRELATIONTYPE_RES.fields_by_name['relation_type'].message_type = _TYPE
_CONCEPTMANAGER_PUTRELATIONTYPE_RES.containing_type = _CONCEPTMANAGER_PUTRELATIONTYPE
_CONCEPTMANAGER_PUTRELATIONTYPE.containing_type = _CONCEPTMANAGER
_CONCEPT.fields_by_name['thing'].message_type = _THING
_CONCEPT.fields_by_name['type'].message_type = _TYPE
_CONCEPT.oneofs_by_name['concept'].fields.append(
  _CONCEPT.fields_by_name['thing'])
_CONCEPT.fields_by_name['thing'].containing_oneof = _CONCEPT.oneofs_by_name['concept']
_CONCEPT.oneofs_by_name['concept'].fields.append(
  _CONCEPT.fields_by_name['type'])
_CONCEPT.fields_by_name['type'].containing_oneof = _CONCEPT.oneofs_by_name['concept']
_THING_REQ.fields_by_name['thing_delete_req'].message_type = _THING_DELETE_REQ
_THING_REQ.fields_by_name['thing_get_type_req'].message_type = _THING_GETTYPE_REQ
_THING_REQ.fields_by_name['thing_is_inferred_req'].message_type = _THING_ISINFERRED_REQ
_THING_REQ.fields_by_name['thing_set_has_req'].message_type = _THING_SETHAS_REQ
_THING_REQ.fields_by_name['thing_unset_has_req'].message_type = _THING_UNSETHAS_REQ
_THING_REQ.fields_by_name['thing_get_has_req'].message_type = _THING_GETHAS_REQ
_THING_REQ.fields_by_name['thing_get_relations_req'].message_type = _THING_GETRELATIONS_REQ
_THING_REQ.fields_by_name['thing_get_plays_req'].message_type = _THING_GETPLAYS_REQ
_THING_REQ.fields_by_name['relation_add_player_req'].message_type = _RELATION_ADDPLAYER_REQ
_THING_REQ.fields_by_name['relation_remove_player_req'].message_type = _RELATION_REMOVEPLAYER_REQ
_THING_REQ.fields_by_name['relation_get_players_req'].message_type = _RELATION_GETPLAYERS_REQ
_THING_REQ.fields_by_name['relation_get_players_by_role_type_req'].message_type = _RELATION_GETPLAYERSBYROLETYPE_REQ
_THING_REQ.fields_by_name['attribute_get_owners_req'].message_type = _ATTRIBUTE_GETOWNERS_REQ
_THING_REQ.containing_type = _THING
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_delete_req'])
_THING_REQ.fields_by_name['thing_delete_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_get_type_req'])
_THING_REQ.fields_by_name['thing_get_type_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_is_inferred_req'])
_THING_REQ.fields_by_name['thing_is_inferred_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_set_has_req'])
_THING_REQ.fields_by_name['thing_set_has_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_unset_has_req'])
_THING_REQ.fields_by_name['thing_unset_has_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_get_has_req'])
_THING_REQ.fields_by_name['thing_get_has_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_get_relations_req'])
_THING_REQ.fields_by_name['thing_get_relations_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['thing_get_plays_req'])
_THING_REQ.fields_by_name['thing_get_plays_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['relation_add_player_req'])
_THING_REQ.fields_by_name['relation_add_player_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['relation_remove_player_req'])
_THING_REQ.fields_by_name['relation_remove_player_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['relation_get_players_req'])
_THING_REQ.fields_by_name['relation_get_players_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['relation_get_players_by_role_type_req'])
_THING_REQ.fields_by_name['relation_get_players_by_role_type_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_REQ.oneofs_by_name['req'].fields.append(
  _THING_REQ.fields_by_name['attribute_get_owners_req'])
_THING_REQ.fields_by_name['attribute_get_owners_req'].containing_oneof = _THING_REQ.oneofs_by_name['req']
_THING_RES.fields_by_name['thing_delete_res'].message_type = _THING_DELETE_RES
_THING_RES.fields_by_name['thing_get_type_res'].message_type = _THING_GETTYPE_RES
_THING_RES.fields_by_name['thing_is_inferred_res'].message_type = _THING_ISINFERRED_RES
_THING_RES.fields_by_name['thing_set_has_res'].message_type = _THING_SETHAS_RES
_THING_RES.fields_by_name['thing_unset_has_res'].message_type = _THING_UNSETHAS_RES
_THING_RES.fields_by_name['thing_get_has_res'].message_type = _THING_GETHAS_RES
_THING_RES.fields_by_name['thing_get_relations_res'].message_type = _THING_GETRELATIONS_RES
_THING_RES.fields_by_name['thing_get_plays_res'].message_type = _THING_GETPLAYS_RES
_THING_RES.fields_by_name['relation_add_player_res'].message_type = _RELATION_ADDPLAYER_RES
_THING_RES.fields_by_name['relation_remove_player_res'].message_type = _RELATION_REMOVEPLAYER_RES
_THING_RES.fields_by_name['relation_get_players_res'].message_type = _RELATION_GETPLAYERS_RES
_THING_RES.fields_by_name['relation_get_players_by_role_type_res'].message_type = _RELATION_GETPLAYERSBYROLETYPE_RES
_THING_RES.fields_by_name['attribute_get_owners_res'].message_type = _ATTRIBUTE_GETOWNERS_RES
_THING_RES.containing_type = _THING
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_delete_res'])
_THING_RES.fields_by_name['thing_delete_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_get_type_res'])
_THING_RES.fields_by_name['thing_get_type_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_is_inferred_res'])
_THING_RES.fields_by_name['thing_is_inferred_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_set_has_res'])
_THING_RES.fields_by_name['thing_set_has_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_unset_has_res'])
_THING_RES.fields_by_name['thing_unset_has_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_get_has_res'])
_THING_RES.fields_by_name['thing_get_has_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_get_relations_res'])
_THING_RES.fields_by_name['thing_get_relations_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['thing_get_plays_res'])
_THING_RES.fields_by_name['thing_get_plays_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['relation_add_player_res'])
_THING_RES.fields_by_name['relation_add_player_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['relation_remove_player_res'])
_THING_RES.fields_by_name['relation_remove_player_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['relation_get_players_res'])
_THING_RES.fields_by_name['relation_get_players_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['relation_get_players_by_role_type_res'])
_THING_RES.fields_by_name['relation_get_players_by_role_type_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_RES.oneofs_by_name['res'].fields.append(
  _THING_RES.fields_by_name['attribute_get_owners_res'])
_THING_RES.fields_by_name['attribute_get_owners_res'].containing_oneof = _THING_RES.oneofs_by_name['res']
_THING_DELETE_REQ.containing_type = _THING_DELETE
_THING_DELETE_RES.containing_type = _THING_DELETE
_THING_DELETE.containing_type = _THING
_THING_ISINFERRED_REQ.containing_type = _THING_ISINFERRED
_THING_ISINFERRED_RES.containing_type = _THING_ISINFERRED
_THING_ISINFERRED.containing_type = _THING
_THING_GETTYPE_REQ.containing_type = _THING_GETTYPE
_THING_GETTYPE_RES.fields_by_name['thing_type'].message_type = _TYPE
_THING_GETTYPE_RES.containing_type = _THING_GETTYPE
_THING_GETTYPE.containing_type = _THING
_THING_SETHAS_REQ.fields_by_name['attribute'].message_type = _THING
_THING_SETHAS_REQ.containing_type = _THING_SETHAS
_THING_SETHAS_RES.containing_type = _THING_SETHAS
_THING_SETHAS.containing_type = _THING
_THING_UNSETHAS_REQ.fields_by_name['attribute'].message_type = _THING
_THING_UNSETHAS_REQ.containing_type = _THING_UNSETHAS
_THING_UNSETHAS_RES.containing_type = _THING_UNSETHAS
_THING_UNSETHAS.containing_type = _THING
_THING_GETHAS_REQ.fields_by_name['attribute_types'].message_type = _TYPE
_THING_GETHAS_REQ.containing_type = _THING_GETHAS
_THING_GETHAS_RES.fields_by_name['attributes'].message_type = _THING
_THING_GETHAS_RES.containing_type = _THING_GETHAS
_THING_GETHAS.containing_type = _THING
_THING_GETPLAYS_REQ.containing_type = _THING_GETPLAYS
_THING_GETPLAYS_RES.fields_by_name['role_types'].message_type = _TYPE
_THING_GETPLAYS_RES.containing_type = _THING_GETPLAYS
_THING_GETPLAYS.containing_type = _THING
_THING_GETRELATIONS_REQ.fields_by_name['role_types'].message_type = _TYPE
_THING_GETRELATIONS_REQ.containing_type = _THING_GETRELATIONS
_THING_GETRELATIONS_RES.fields_by_name['relations'].message_type = _THING
_THING_GETRELATIONS_RES.containing_type = _THING_GETRELATIONS
_THING_GETRELATIONS.containing_type = _THING
_THING.fields_by_name['type'].message_type = _TYPE
_THING.fields_by_name['value'].message_type = _ATTRIBUTE_VALUE
_RELATION_GETPLAYERS_REQ.fields_by_name['role_types'].message_type = _TYPE
_RELATION_GETPLAYERS_REQ.containing_type = _RELATION_GETPLAYERS
_RELATION_GETPLAYERS_RES.fields_by_name['things'].message_type = _THING
_RELATION_GETPLAYERS_RES.containing_type = _RELATION_GETPLAYERS
_RELATION_GETPLAYERS.containing_type = _RELATION
_RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER.fields_by_name['role_type'].message_type = _TYPE
_RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER.fields_by_name['player'].message_type = _THING
_RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER.containing_type = _RELATION_GETPLAYERSBYROLETYPE
_RELATION_GETPLAYERSBYROLETYPE_REQ.containing_type = _RELATION_GETPLAYERSBYROLETYPE
_RELATION_GETPLAYERSBYROLETYPE_RES.fields_by_name['role_types_with_players'].message_type = _RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER
_RELATION_GETPLAYERSBYROLETYPE_RES.containing_type = _RELATION_GETPLAYERSBYROLETYPE
_RELATION_GETPLAYERSBYROLETYPE.containing_type = _RELATION
_RELATION_ADDPLAYER_REQ.fields_by_name['role_type'].message_type = _TYPE
_RELATION_ADDPLAYER_REQ.fields_by_name['player'].message_type = _THING
_RELATION_ADDPLAYER_REQ.containing_type = _RELATION_ADDPLAYER
_RELATION_ADDPLAYER_RES.containing_type = _RELATION_ADDPLAYER
_RELATION_ADDPLAYER.containing_type = _RELATION
_RELATION_REMOVEPLAYER_REQ.fields_by_name['role_type'].message_type = _TYPE
_RELATION_REMOVEPLAYER_REQ.fields_by_name['player'].message_type = _THING
_RELATION_REMOVEPLAYER_REQ.containing_type = _RELATION_REMOVEPLAYER
_RELATION_REMOVEPLAYER_RES.containing_type = _RELATION_REMOVEPLAYER
_RELATION_REMOVEPLAYER.containing_type = _RELATION
_ATTRIBUTE_GETOWNERS_REQ.fields_by_name['thing_type'].message_type = _TYPE
_ATTRIBUTE_GETOWNERS_REQ.containing_type = _ATTRIBUTE_GETOWNERS
_ATTRIBUTE_GETOWNERS_REQ.oneofs_by_name['filter'].fields.append(
  _ATTRIBUTE_GETOWNERS_REQ.fields_by_name['thing_type'])
_ATTRIBUTE_GETOWNERS_REQ.fields_by_name['thing_type'].containing_oneof = _ATTRIBUTE_GETOWNERS_REQ.oneofs_by_name['filter']
_ATTRIBUTE_GETOWNERS_RES.fields_by_name['things'].message_type = _THING
_ATTRIBUTE_GETOWNERS_RES.containing_type = _ATTRIBUTE_GETOWNERS
_ATTRIBUTE_GETOWNERS.containing_type = _ATTRIBUTE
_ATTRIBUTE_VALUE.containing_type = _ATTRIBUTE
_ATTRIBUTE_VALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTE_VALUE.fields_by_name['string'])
_ATTRIBUTE_VALUE.fields_by_name['string'].containing_oneof = _ATTRIBUTE_VALUE.oneofs_by_name['value']
_ATTRIBUTE_VALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTE_VALUE.fields_by_name['boolean'])
_ATTRIBUTE_VALUE.fields_by_name['boolean'].containing_oneof = _ATTRIBUTE_VALUE.oneofs_by_name['value']
_ATTRIBUTE_VALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTE_VALUE.fields_by_name['long'])
_ATTRIBUTE_VALUE.fields_by_name['long'].containing_oneof = _ATTRIBUTE_VALUE.oneofs_by_name['value']
_ATTRIBUTE_VALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTE_VALUE.fields_by_name['double'])
_ATTRIBUTE_VALUE.fields_by_name['double'].containing_oneof = _ATTRIBUTE_VALUE.oneofs_by_name['value']
_ATTRIBUTE_VALUE.oneofs_by_name['value'].fields.append(
  _ATTRIBUTE_VALUE.fields_by_name['date_time'])
_ATTRIBUTE_VALUE.fields_by_name['date_time'].containing_oneof = _ATTRIBUTE_VALUE.oneofs_by_name['value']
_TYPE_REQ.fields_by_name['type_delete_req'].message_type = _TYPE_DELETE_REQ
_TYPE_REQ.fields_by_name['type_set_label_req'].message_type = _TYPE_SETLABEL_REQ
_TYPE_REQ.fields_by_name['type_is_abstract_req'].message_type = _TYPE_ISABSTRACT_REQ
_TYPE_REQ.fields_by_name['type_get_supertype_req'].message_type = _TYPE_GETSUPERTYPE_REQ
_TYPE_REQ.fields_by_name['type_set_supertype_req'].message_type = _TYPE_SETSUPERTYPE_REQ
_TYPE_REQ.fields_by_name['type_get_supertypes_req'].message_type = _TYPE_GETSUPERTYPES_REQ
_TYPE_REQ.fields_by_name['type_get_subtypes_req'].message_type = _TYPE_GETSUBTYPES_REQ
_TYPE_REQ.fields_by_name['role_type_get_relation_type_req'].message_type = _ROLETYPE_GETRELATIONTYPE_REQ
_TYPE_REQ.fields_by_name['role_type_get_relation_types_req'].message_type = _ROLETYPE_GETRELATIONTYPES_REQ
_TYPE_REQ.fields_by_name['role_type_get_players_req'].message_type = _ROLETYPE_GETPLAYERS_REQ
_TYPE_REQ.fields_by_name['thing_type_set_abstract_req'].message_type = _THINGTYPE_SETABSTRACT_REQ
_TYPE_REQ.fields_by_name['thing_type_unset_abstract_req'].message_type = _THINGTYPE_UNSETABSTRACT_REQ
_TYPE_REQ.fields_by_name['thing_type_set_owns_req'].message_type = _THINGTYPE_SETOWNS_REQ
_TYPE_REQ.fields_by_name['thing_type_unset_owns_req'].message_type = _THINGTYPE_UNSETOWNS_REQ
_TYPE_REQ.fields_by_name['thing_type_set_plays_req'].message_type = _THINGTYPE_SETPLAYS_REQ
_TYPE_REQ.fields_by_name['thing_type_unset_plays_req'].message_type = _THINGTYPE_UNSETPLAYS_REQ
_TYPE_REQ.fields_by_name['thing_type_get_instances_req'].message_type = _THINGTYPE_GETINSTANCES_REQ
_TYPE_REQ.fields_by_name['thing_type_get_owns_req'].message_type = _THINGTYPE_GETOWNS_REQ
_TYPE_REQ.fields_by_name['thing_type_get_plays_req'].message_type = _THINGTYPE_GETPLAYS_REQ
_TYPE_REQ.fields_by_name['entity_type_create_req'].message_type = _ENTITYTYPE_CREATE_REQ
_TYPE_REQ.fields_by_name['relation_type_create_req'].message_type = _RELATIONTYPE_CREATE_REQ
_TYPE_REQ.fields_by_name['relation_type_get_relates_for_role_label_req'].message_type = _RELATIONTYPE_GETRELATESFORROLELABEL_REQ
_TYPE_REQ.fields_by_name['relation_type_set_relates_req'].message_type = _RELATIONTYPE_SETRELATES_REQ
_TYPE_REQ.fields_by_name['relation_type_unset_relates_req'].message_type = _RELATIONTYPE_UNSETRELATES_REQ
_TYPE_REQ.fields_by_name['relation_type_get_relates_req'].message_type = _RELATIONTYPE_GETRELATES_REQ
_TYPE_REQ.fields_by_name['attribute_type_put_req'].message_type = _ATTRIBUTETYPE_PUT_REQ
_TYPE_REQ.fields_by_name['attribute_type_get_req'].message_type = _ATTRIBUTETYPE_GET_REQ
_TYPE_REQ.fields_by_name['attribute_type_get_regex_req'].message_type = _ATTRIBUTETYPE_GETREGEX_REQ
_TYPE_REQ.fields_by_name['attribute_type_set_regex_req'].message_type = _ATTRIBUTETYPE_SETREGEX_REQ
_TYPE_REQ.fields_by_name['attribute_type_get_owners_req'].message_type = _ATTRIBUTETYPE_GETOWNERS_REQ
_TYPE_REQ.containing_type = _TYPE
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_delete_req'])
_TYPE_REQ.fields_by_name['type_delete_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_set_label_req'])
_TYPE_REQ.fields_by_name['type_set_label_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_is_abstract_req'])
_TYPE_REQ.fields_by_name['type_is_abstract_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_get_supertype_req'])
_TYPE_REQ.fields_by_name['type_get_supertype_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_set_supertype_req'])
_TYPE_REQ.fields_by_name['type_set_supertype_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_get_supertypes_req'])
_TYPE_REQ.fields_by_name['type_get_supertypes_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['type_get_subtypes_req'])
_TYPE_REQ.fields_by_name['type_get_subtypes_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['role_type_get_relation_type_req'])
_TYPE_REQ.fields_by_name['role_type_get_relation_type_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['role_type_get_relation_types_req'])
_TYPE_REQ.fields_by_name['role_type_get_relation_types_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['role_type_get_players_req'])
_TYPE_REQ.fields_by_name['role_type_get_players_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_set_abstract_req'])
_TYPE_REQ.fields_by_name['thing_type_set_abstract_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_unset_abstract_req'])
_TYPE_REQ.fields_by_name['thing_type_unset_abstract_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_set_owns_req'])
_TYPE_REQ.fields_by_name['thing_type_set_owns_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_unset_owns_req'])
_TYPE_REQ.fields_by_name['thing_type_unset_owns_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_set_plays_req'])
_TYPE_REQ.fields_by_name['thing_type_set_plays_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_unset_plays_req'])
_TYPE_REQ.fields_by_name['thing_type_unset_plays_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_get_instances_req'])
_TYPE_REQ.fields_by_name['thing_type_get_instances_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_get_owns_req'])
_TYPE_REQ.fields_by_name['thing_type_get_owns_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['thing_type_get_plays_req'])
_TYPE_REQ.fields_by_name['thing_type_get_plays_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['entity_type_create_req'])
_TYPE_REQ.fields_by_name['entity_type_create_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['relation_type_create_req'])
_TYPE_REQ.fields_by_name['relation_type_create_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['relation_type_get_relates_for_role_label_req'])
_TYPE_REQ.fields_by_name['relation_type_get_relates_for_role_label_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['relation_type_set_relates_req'])
_TYPE_REQ.fields_by_name['relation_type_set_relates_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['relation_type_unset_relates_req'])
_TYPE_REQ.fields_by_name['relation_type_unset_relates_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['relation_type_get_relates_req'])
_TYPE_REQ.fields_by_name['relation_type_get_relates_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['attribute_type_put_req'])
_TYPE_REQ.fields_by_name['attribute_type_put_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['attribute_type_get_req'])
_TYPE_REQ.fields_by_name['attribute_type_get_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['attribute_type_get_regex_req'])
_TYPE_REQ.fields_by_name['attribute_type_get_regex_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['attribute_type_set_regex_req'])
_TYPE_REQ.fields_by_name['attribute_type_set_regex_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_REQ.oneofs_by_name['req'].fields.append(
  _TYPE_REQ.fields_by_name['attribute_type_get_owners_req'])
_TYPE_REQ.fields_by_name['attribute_type_get_owners_req'].containing_oneof = _TYPE_REQ.oneofs_by_name['req']
_TYPE_RES.fields_by_name['type_delete_res'].message_type = _TYPE_DELETE_RES
_TYPE_RES.fields_by_name['type_set_label_res'].message_type = _TYPE_SETLABEL_RES
_TYPE_RES.fields_by_name['type_is_abstract_res'].message_type = _TYPE_ISABSTRACT_RES
_TYPE_RES.fields_by_name['type_get_supertype_res'].message_type = _TYPE_GETSUPERTYPE_RES
_TYPE_RES.fields_by_name['type_set_supertype_res'].message_type = _TYPE_SETSUPERTYPE_RES
_TYPE_RES.fields_by_name['type_get_supertypes_res'].message_type = _TYPE_GETSUPERTYPES_RES
_TYPE_RES.fields_by_name['type_get_subtypes_res'].message_type = _TYPE_GETSUBTYPES_RES
_TYPE_RES.fields_by_name['role_type_get_relation_type_res'].message_type = _ROLETYPE_GETRELATIONTYPE_RES
_TYPE_RES.fields_by_name['role_type_get_relation_types_res'].message_type = _ROLETYPE_GETRELATIONTYPES_RES
_TYPE_RES.fields_by_name['role_type_get_players_res'].message_type = _ROLETYPE_GETPLAYERS_RES
_TYPE_RES.fields_by_name['thing_type_set_abstract_res'].message_type = _THINGTYPE_SETABSTRACT_RES
_TYPE_RES.fields_by_name['thing_type_unset_abstract_res'].message_type = _THINGTYPE_UNSETABSTRACT_RES
_TYPE_RES.fields_by_name['thing_type_set_owns_res'].message_type = _THINGTYPE_SETOWNS_RES
_TYPE_RES.fields_by_name['thing_type_unset_owns_res'].message_type = _THINGTYPE_UNSETOWNS_RES
_TYPE_RES.fields_by_name['thing_type_set_plays_res'].message_type = _THINGTYPE_SETPLAYS_RES
_TYPE_RES.fields_by_name['thing_type_unset_plays_res'].message_type = _THINGTYPE_UNSETPLAYS_RES
_TYPE_RES.fields_by_name['thing_type_get_instances_res'].message_type = _THINGTYPE_GETINSTANCES_RES
_TYPE_RES.fields_by_name['thing_type_get_owns_res'].message_type = _THINGTYPE_GETOWNS_RES
_TYPE_RES.fields_by_name['thing_type_get_plays_res'].message_type = _THINGTYPE_GETPLAYS_RES
_TYPE_RES.fields_by_name['entity_type_create_res'].message_type = _ENTITYTYPE_CREATE_RES
_TYPE_RES.fields_by_name['relation_type_create_res'].message_type = _RELATIONTYPE_CREATE_RES
_TYPE_RES.fields_by_name['relation_type_get_relates_for_role_label_res'].message_type = _RELATIONTYPE_GETRELATESFORROLELABEL_RES
_TYPE_RES.fields_by_name['relation_type_set_relates_res'].message_type = _RELATIONTYPE_SETRELATES_RES
_TYPE_RES.fields_by_name['relation_type_unset_relates_res'].message_type = _RELATIONTYPE_UNSETRELATES_RES
_TYPE_RES.fields_by_name['relation_type_get_relates_res'].message_type = _RELATIONTYPE_GETRELATES_RES
_TYPE_RES.fields_by_name['attribute_type_put_res'].message_type = _ATTRIBUTETYPE_PUT_RES
_TYPE_RES.fields_by_name['attribute_type_get_res'].message_type = _ATTRIBUTETYPE_GET_RES
_TYPE_RES.fields_by_name['attribute_type_get_regex_res'].message_type = _ATTRIBUTETYPE_GETREGEX_RES
_TYPE_RES.fields_by_name['attribute_type_set_regex_res'].message_type = _ATTRIBUTETYPE_SETREGEX_RES
_TYPE_RES.fields_by_name['attribute_type_get_owners_res'].message_type = _ATTRIBUTETYPE_GETOWNERS_RES
_TYPE_RES.containing_type = _TYPE
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_delete_res'])
_TYPE_RES.fields_by_name['type_delete_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_set_label_res'])
_TYPE_RES.fields_by_name['type_set_label_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_is_abstract_res'])
_TYPE_RES.fields_by_name['type_is_abstract_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_get_supertype_res'])
_TYPE_RES.fields_by_name['type_get_supertype_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_set_supertype_res'])
_TYPE_RES.fields_by_name['type_set_supertype_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_get_supertypes_res'])
_TYPE_RES.fields_by_name['type_get_supertypes_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['type_get_subtypes_res'])
_TYPE_RES.fields_by_name['type_get_subtypes_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['role_type_get_relation_type_res'])
_TYPE_RES.fields_by_name['role_type_get_relation_type_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['role_type_get_relation_types_res'])
_TYPE_RES.fields_by_name['role_type_get_relation_types_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['role_type_get_players_res'])
_TYPE_RES.fields_by_name['role_type_get_players_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_set_abstract_res'])
_TYPE_RES.fields_by_name['thing_type_set_abstract_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_unset_abstract_res'])
_TYPE_RES.fields_by_name['thing_type_unset_abstract_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_set_owns_res'])
_TYPE_RES.fields_by_name['thing_type_set_owns_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_unset_owns_res'])
_TYPE_RES.fields_by_name['thing_type_unset_owns_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_set_plays_res'])
_TYPE_RES.fields_by_name['thing_type_set_plays_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_unset_plays_res'])
_TYPE_RES.fields_by_name['thing_type_unset_plays_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_get_instances_res'])
_TYPE_RES.fields_by_name['thing_type_get_instances_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_get_owns_res'])
_TYPE_RES.fields_by_name['thing_type_get_owns_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['thing_type_get_plays_res'])
_TYPE_RES.fields_by_name['thing_type_get_plays_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['entity_type_create_res'])
_TYPE_RES.fields_by_name['entity_type_create_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['relation_type_create_res'])
_TYPE_RES.fields_by_name['relation_type_create_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['relation_type_get_relates_for_role_label_res'])
_TYPE_RES.fields_by_name['relation_type_get_relates_for_role_label_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['relation_type_set_relates_res'])
_TYPE_RES.fields_by_name['relation_type_set_relates_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['relation_type_unset_relates_res'])
_TYPE_RES.fields_by_name['relation_type_unset_relates_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['relation_type_get_relates_res'])
_TYPE_RES.fields_by_name['relation_type_get_relates_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['attribute_type_put_res'])
_TYPE_RES.fields_by_name['attribute_type_put_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['attribute_type_get_res'])
_TYPE_RES.fields_by_name['attribute_type_get_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['attribute_type_get_regex_res'])
_TYPE_RES.fields_by_name['attribute_type_get_regex_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['attribute_type_set_regex_res'])
_TYPE_RES.fields_by_name['attribute_type_set_regex_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_RES.fields_by_name['attribute_type_get_owners_res'])
_TYPE_RES.fields_by_name['attribute_type_get_owners_res'].containing_oneof = _TYPE_RES.oneofs_by_name['res']
_TYPE_DELETE_REQ.containing_type = _TYPE_DELETE
_TYPE_DELETE_RES.containing_type = _TYPE_DELETE
_TYPE_DELETE.containing_type = _TYPE
_TYPE_SETLABEL_REQ.containing_type = _TYPE_SETLABEL
_TYPE_SETLABEL_RES.containing_type = _TYPE_SETLABEL
_TYPE_SETLABEL.containing_type = _TYPE
_TYPE_ISABSTRACT_REQ.containing_type = _TYPE_ISABSTRACT
_TYPE_ISABSTRACT_RES.containing_type = _TYPE_ISABSTRACT
_TYPE_ISABSTRACT.containing_type = _TYPE
_TYPE_GETSUPERTYPE_REQ.containing_type = _TYPE_GETSUPERTYPE
_TYPE_GETSUPERTYPE_RES.fields_by_name['type'].message_type = _TYPE
_TYPE_GETSUPERTYPE_RES.containing_type = _TYPE_GETSUPERTYPE
_TYPE_GETSUPERTYPE_RES.oneofs_by_name['res'].fields.append(
  _TYPE_GETSUPERTYPE_RES.fields_by_name['type'])
_TYPE_GETSUPERTYPE_RES.fields_by_name['type'].containing_oneof = _TYPE_GETSUPERTYPE_RES.oneofs_by_name['res']
_TYPE_GETSUPERTYPE.containing_type = _TYPE
_TYPE_SETSUPERTYPE_REQ.fields_by_name['type'].message_type = _TYPE
_TYPE_SETSUPERTYPE_REQ.containing_type = _TYPE_SETSUPERTYPE
_TYPE_SETSUPERTYPE_RES.containing_type = _TYPE_SETSUPERTYPE
_TYPE_SETSUPERTYPE.containing_type = _TYPE
_TYPE_GETSUPERTYPES_REQ.containing_type = _TYPE_GETSUPERTYPES
_TYPE_GETSUPERTYPES_RES.fields_by_name['types'].message_type = _TYPE
_TYPE_GETSUPERTYPES_RES.containing_type = _TYPE_GETSUPERTYPES
_TYPE_GETSUPERTYPES.containing_type = _TYPE
_TYPE_GETSUBTYPES_REQ.containing_type = _TYPE_GETSUBTYPES
_TYPE_GETSUBTYPES_RES.fields_by_name['types'].message_type = _TYPE
_TYPE_GETSUBTYPES_RES.containing_type = _TYPE_GETSUBTYPES
_TYPE_GETSUBTYPES.containing_type = _TYPE
_TYPE.fields_by_name['encoding'].enum_type = _TYPE_ENCODING
_TYPE.fields_by_name['value_type'].enum_type = _ATTRIBUTETYPE_VALUETYPE
_TYPE_ENCODING.containing_type = _TYPE
_ROLETYPE_GETRELATIONTYPE_REQ.containing_type = _ROLETYPE_GETRELATIONTYPE
_ROLETYPE_GETRELATIONTYPE_RES.fields_by_name['relation_type'].message_type = _TYPE
_ROLETYPE_GETRELATIONTYPE_RES.containing_type = _ROLETYPE_GETRELATIONTYPE
_ROLETYPE_GETRELATIONTYPE.containing_type = _ROLETYPE
_ROLETYPE_GETRELATIONTYPES_REQ.containing_type = _ROLETYPE_GETRELATIONTYPES
_ROLETYPE_GETRELATIONTYPES_RES.fields_by_name['relation_types'].message_type = _TYPE
_ROLETYPE_GETRELATIONTYPES_RES.containing_type = _ROLETYPE_GETRELATIONTYPES
_ROLETYPE_GETRELATIONTYPES.containing_type = _ROLETYPE
_ROLETYPE_GETPLAYERS_REQ.containing_type = _ROLETYPE_GETPLAYERS
_ROLETYPE_GETPLAYERS_RES.fields_by_name['thing_types'].message_type = _TYPE
_ROLETYPE_GETPLAYERS_RES.containing_type = _ROLETYPE_GETPLAYERS
_ROLETYPE_GETPLAYERS.containing_type = _ROLETYPE
_THINGTYPE_SETABSTRACT_REQ.containing_type = _THINGTYPE_SETABSTRACT
_THINGTYPE_SETABSTRACT_RES.containing_type = _THINGTYPE_SETABSTRACT
_THINGTYPE_SETABSTRACT.containing_type = _THINGTYPE
_THINGTYPE_UNSETABSTRACT_REQ.containing_type = _THINGTYPE_UNSETABSTRACT
_THINGTYPE_UNSETABSTRACT_RES.containing_type = _THINGTYPE_UNSETABSTRACT
_THINGTYPE_UNSETABSTRACT.containing_type = _THINGTYPE
_THINGTYPE_GETINSTANCES_REQ.containing_type = _THINGTYPE_GETINSTANCES
_THINGTYPE_GETINSTANCES_RES.fields_by_name['things'].message_type = _THING
_THINGTYPE_GETINSTANCES_RES.containing_type = _THINGTYPE_GETINSTANCES
_THINGTYPE_GETINSTANCES.containing_type = _THINGTYPE
_THINGTYPE_GETOWNS_REQ.fields_by_name['value_type'].enum_type = _ATTRIBUTETYPE_VALUETYPE
_THINGTYPE_GETOWNS_REQ.containing_type = _THINGTYPE_GETOWNS
_THINGTYPE_GETOWNS_REQ.oneofs_by_name['filter'].fields.append(
  _THINGTYPE_GETOWNS_REQ.fields_by_name['value_type'])
_THINGTYPE_GETOWNS_REQ.fields_by_name['value_type'].containing_oneof = _THINGTYPE_GETOWNS_REQ.oneofs_by_name['filter']
_THINGTYPE_GETOWNS_RES.fields_by_name['attribute_types'].message_type = _TYPE
_THINGTYPE_GETOWNS_RES.containing_type = _THINGTYPE_GETOWNS
_THINGTYPE_GETOWNS.containing_type = _THINGTYPE
_THINGTYPE_GETPLAYS_REQ.containing_type = _THINGTYPE_GETPLAYS
_THINGTYPE_GETPLAYS_RES.fields_by_name['roles'].message_type = _TYPE
_THINGTYPE_GETPLAYS_RES.containing_type = _THINGTYPE_GETPLAYS
_THINGTYPE_GETPLAYS.containing_type = _THINGTYPE
_THINGTYPE_SETOWNS_REQ.fields_by_name['attribute_type'].message_type = _TYPE
_THINGTYPE_SETOWNS_REQ.fields_by_name['overridden_type'].message_type = _TYPE
_THINGTYPE_SETOWNS_REQ.containing_type = _THINGTYPE_SETOWNS
_THINGTYPE_SETOWNS_REQ.oneofs_by_name['overridden'].fields.append(
  _THINGTYPE_SETOWNS_REQ.fields_by_name['overridden_type'])
_THINGTYPE_SETOWNS_REQ.fields_by_name['overridden_type'].containing_oneof = _THINGTYPE_SETOWNS_REQ.oneofs_by_name['overridden']
_THINGTYPE_SETOWNS_RES.containing_type = _THINGTYPE_SETOWNS
_THINGTYPE_SETOWNS.containing_type = _THINGTYPE
_THINGTYPE_SETPLAYS_REQ.fields_by_name['role'].message_type = _TYPE
_THINGTYPE_SETPLAYS_REQ.fields_by_name['overridden_role'].message_type = _TYPE
_THINGTYPE_SETPLAYS_REQ.containing_type = _THINGTYPE_SETPLAYS
_THINGTYPE_SETPLAYS_REQ.oneofs_by_name['overridden'].fields.append(
  _THINGTYPE_SETPLAYS_REQ.fields_by_name['overridden_role'])
_THINGTYPE_SETPLAYS_REQ.fields_by_name['overridden_role'].containing_oneof = _THINGTYPE_SETPLAYS_REQ.oneofs_by_name['overridden']
_THINGTYPE_SETPLAYS_RES.containing_type = _THINGTYPE_SETPLAYS
_THINGTYPE_SETPLAYS.containing_type = _THINGTYPE
_THINGTYPE_UNSETOWNS_REQ.fields_by_name['attribute_type'].message_type = _TYPE
_THINGTYPE_UNSETOWNS_REQ.containing_type = _THINGTYPE_UNSETOWNS
_THINGTYPE_UNSETOWNS_RES.containing_type = _THINGTYPE_UNSETOWNS
_THINGTYPE_UNSETOWNS.containing_type = _THINGTYPE
_THINGTYPE_UNSETPLAYS_REQ.fields_by_name['role'].message_type = _TYPE
_THINGTYPE_UNSETPLAYS_REQ.containing_type = _THINGTYPE_UNSETPLAYS
_THINGTYPE_UNSETPLAYS_RES.containing_type = _THINGTYPE_UNSETPLAYS
_THINGTYPE_UNSETPLAYS.containing_type = _THINGTYPE
_ENTITYTYPE_CREATE_REQ.containing_type = _ENTITYTYPE_CREATE
_ENTITYTYPE_CREATE_RES.fields_by_name['entity'].message_type = _THING
_ENTITYTYPE_CREATE_RES.containing_type = _ENTITYTYPE_CREATE
_ENTITYTYPE_CREATE.containing_type = _ENTITYTYPE
_RELATIONTYPE_CREATE_REQ.containing_type = _RELATIONTYPE_CREATE
_RELATIONTYPE_CREATE_RES.fields_by_name['relation'].message_type = _THING
_RELATIONTYPE_CREATE_RES.containing_type = _RELATIONTYPE_CREATE
_RELATIONTYPE_CREATE.containing_type = _RELATIONTYPE
_RELATIONTYPE_GETRELATES_REQ.containing_type = _RELATIONTYPE_GETRELATES
_RELATIONTYPE_GETRELATES_RES.fields_by_name['roles'].message_type = _TYPE
_RELATIONTYPE_GETRELATES_RES.containing_type = _RELATIONTYPE_GETRELATES
_RELATIONTYPE_GETRELATES.containing_type = _RELATIONTYPE
_RELATIONTYPE_GETRELATESFORROLELABEL_REQ.containing_type = _RELATIONTYPE_GETRELATESFORROLELABEL
_RELATIONTYPE_GETRELATESFORROLELABEL_RES.fields_by_name['role_type'].message_type = _TYPE
_RELATIONTYPE_GETRELATESFORROLELABEL_RES.containing_type = _RELATIONTYPE_GETRELATESFORROLELABEL
_RELATIONTYPE_GETRELATESFORROLELABEL_RES.oneofs_by_name['role'].fields.append(
  _RELATIONTYPE_GETRELATESFORROLELABEL_RES.fields_by_name['role_type'])
_RELATIONTYPE_GETRELATESFORROLELABEL_RES.fields_by_name['role_type'].containing_oneof = _RELATIONTYPE_GETRELATESFORROLELABEL_RES.oneofs_by_name['role']
_RELATIONTYPE_GETRELATESFORROLELABEL.containing_type = _RELATIONTYPE
_RELATIONTYPE_SETRELATES_REQ.containing_type = _RELATIONTYPE_SETRELATES
_RELATIONTYPE_SETRELATES_REQ.oneofs_by_name['overridden'].fields.append(
  _RELATIONTYPE_SETRELATES_REQ.fields_by_name['overridden_label'])
_RELATIONTYPE_SETRELATES_REQ.fields_by_name['overridden_label'].containing_oneof = _RELATIONTYPE_SETRELATES_REQ.oneofs_by_name['overridden']
_RELATIONTYPE_SETRELATES_RES.containing_type = _RELATIONTYPE_SETRELATES
_RELATIONTYPE_SETRELATES.containing_type = _RELATIONTYPE
_RELATIONTYPE_UNSETRELATES_REQ.containing_type = _RELATIONTYPE_UNSETRELATES
_RELATIONTYPE_UNSETRELATES_RES.containing_type = _RELATIONTYPE_UNSETRELATES
_RELATIONTYPE_UNSETRELATES.containing_type = _RELATIONTYPE
_ATTRIBUTETYPE_PUT_REQ.fields_by_name['value'].message_type = _ATTRIBUTE_VALUE
_ATTRIBUTETYPE_PUT_REQ.containing_type = _ATTRIBUTETYPE_PUT
_ATTRIBUTETYPE_PUT_RES.fields_by_name['attribute'].message_type = _THING
_ATTRIBUTETYPE_PUT_RES.containing_type = _ATTRIBUTETYPE_PUT
_ATTRIBUTETYPE_PUT.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_GET_REQ.fields_by_name['value'].message_type = _ATTRIBUTE_VALUE
_ATTRIBUTETYPE_GET_REQ.containing_type = _ATTRIBUTETYPE_GET
_ATTRIBUTETYPE_GET_RES.fields_by_name['attribute'].message_type = _THING
_ATTRIBUTETYPE_GET_RES.containing_type = _ATTRIBUTETYPE_GET
_ATTRIBUTETYPE_GET_RES.oneofs_by_name['res'].fields.append(
  _ATTRIBUTETYPE_GET_RES.fields_by_name['attribute'])
_ATTRIBUTETYPE_GET_RES.fields_by_name['attribute'].containing_oneof = _ATTRIBUTETYPE_GET_RES.oneofs_by_name['res']
_ATTRIBUTETYPE_GET.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_GETOWNERS_REQ.containing_type = _ATTRIBUTETYPE_GETOWNERS
_ATTRIBUTETYPE_GETOWNERS_RES.fields_by_name['owners'].message_type = _TYPE
_ATTRIBUTETYPE_GETOWNERS_RES.containing_type = _ATTRIBUTETYPE_GETOWNERS
_ATTRIBUTETYPE_GETOWNERS.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_GETREGEX_REQ.containing_type = _ATTRIBUTETYPE_GETREGEX
_ATTRIBUTETYPE_GETREGEX_RES.containing_type = _ATTRIBUTETYPE_GETREGEX
_ATTRIBUTETYPE_GETREGEX.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_SETREGEX_REQ.containing_type = _ATTRIBUTETYPE_SETREGEX
_ATTRIBUTETYPE_SETREGEX_RES.containing_type = _ATTRIBUTETYPE_SETREGEX
_ATTRIBUTETYPE_SETREGEX.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_GETSUBTYPES_REQ.fields_by_name['value_type'].enum_type = _ATTRIBUTETYPE_VALUETYPE
_ATTRIBUTETYPE_GETSUBTYPES_REQ.containing_type = _ATTRIBUTETYPE_GETSUBTYPES
_ATTRIBUTETYPE_GETSUBTYPES_REQ.oneofs_by_name['req'].fields.append(
  _ATTRIBUTETYPE_GETSUBTYPES_REQ.fields_by_name['value_type'])
_ATTRIBUTETYPE_GETSUBTYPES_REQ.fields_by_name['value_type'].containing_oneof = _ATTRIBUTETYPE_GETSUBTYPES_REQ.oneofs_by_name['req']
_ATTRIBUTETYPE_GETSUBTYPES_RES.fields_by_name['types'].message_type = _TYPE
_ATTRIBUTETYPE_GETSUBTYPES_RES.containing_type = _ATTRIBUTETYPE_GETSUBTYPES
_ATTRIBUTETYPE_GETSUBTYPES.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_GETINSTANCES_REQ.fields_by_name['value_type'].enum_type = _ATTRIBUTETYPE_VALUETYPE
_ATTRIBUTETYPE_GETINSTANCES_REQ.containing_type = _ATTRIBUTETYPE_GETINSTANCES
_ATTRIBUTETYPE_GETINSTANCES_REQ.oneofs_by_name['req'].fields.append(
  _ATTRIBUTETYPE_GETINSTANCES_REQ.fields_by_name['value_type'])
_ATTRIBUTETYPE_GETINSTANCES_REQ.fields_by_name['value_type'].containing_oneof = _ATTRIBUTETYPE_GETINSTANCES_REQ.oneofs_by_name['req']
_ATTRIBUTETYPE_GETINSTANCES_RES.fields_by_name['things'].message_type = _THING
_ATTRIBUTETYPE_GETINSTANCES_RES.containing_type = _ATTRIBUTETYPE_GETINSTANCES
_ATTRIBUTETYPE_GETINSTANCES.containing_type = _ATTRIBUTETYPE
_ATTRIBUTETYPE_VALUETYPE.containing_type = _ATTRIBUTETYPE
DESCRIPTOR.message_types_by_name['ConceptManager'] = _CONCEPTMANAGER
DESCRIPTOR.message_types_by_name['Concept'] = _CONCEPT
DESCRIPTOR.message_types_by_name['Thing'] = _THING
DESCRIPTOR.message_types_by_name['Relation'] = _RELATION
DESCRIPTOR.message_types_by_name['Attribute'] = _ATTRIBUTE
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['RoleType'] = _ROLETYPE
DESCRIPTOR.message_types_by_name['ThingType'] = _THINGTYPE
DESCRIPTOR.message_types_by_name['EntityType'] = _ENTITYTYPE
DESCRIPTOR.message_types_by_name['RelationType'] = _RELATIONTYPE
DESCRIPTOR.message_types_by_name['AttributeType'] = _ATTRIBUTETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConceptManager = _reflection.GeneratedProtocolMessageType('ConceptManager', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _CONCEPTMANAGER_REQ,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _CONCEPTMANAGER_RES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.Res)
    ))
  ,

  GetThingType = _reflection.GeneratedProtocolMessageType('GetThingType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_GETTHINGTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThingType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_GETTHINGTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThingType.Res)
      ))
    ,
    DESCRIPTOR = _CONCEPTMANAGER_GETTHINGTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThingType)
    ))
  ,

  GetThing = _reflection.GeneratedProtocolMessageType('GetThing', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_GETTHING_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThing.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_GETTHING_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThing.Res)
      ))
    ,
    DESCRIPTOR = _CONCEPTMANAGER_GETTHING,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.GetThing)
    ))
  ,

  PutEntityType = _reflection.GeneratedProtocolMessageType('PutEntityType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTENTITYTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutEntityType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTENTITYTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutEntityType.Res)
      ))
    ,
    DESCRIPTOR = _CONCEPTMANAGER_PUTENTITYTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutEntityType)
    ))
  ,

  PutAttributeType = _reflection.GeneratedProtocolMessageType('PutAttributeType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTATTRIBUTETYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutAttributeType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTATTRIBUTETYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutAttributeType.Res)
      ))
    ,
    DESCRIPTOR = _CONCEPTMANAGER_PUTATTRIBUTETYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutAttributeType)
    ))
  ,

  PutRelationType = _reflection.GeneratedProtocolMessageType('PutRelationType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTRELATIONTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutRelationType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CONCEPTMANAGER_PUTRELATIONTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutRelationType.Res)
      ))
    ,
    DESCRIPTOR = _CONCEPTMANAGER_PUTRELATIONTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager.PutRelationType)
    ))
  ,
  DESCRIPTOR = _CONCEPTMANAGER,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptManager)
  ))
_sym_db.RegisterMessage(ConceptManager)
_sym_db.RegisterMessage(ConceptManager.Req)
_sym_db.RegisterMessage(ConceptManager.Res)
_sym_db.RegisterMessage(ConceptManager.GetThingType)
_sym_db.RegisterMessage(ConceptManager.GetThingType.Req)
_sym_db.RegisterMessage(ConceptManager.GetThingType.Res)
_sym_db.RegisterMessage(ConceptManager.GetThing)
_sym_db.RegisterMessage(ConceptManager.GetThing.Req)
_sym_db.RegisterMessage(ConceptManager.GetThing.Res)
_sym_db.RegisterMessage(ConceptManager.PutEntityType)
_sym_db.RegisterMessage(ConceptManager.PutEntityType.Req)
_sym_db.RegisterMessage(ConceptManager.PutEntityType.Res)
_sym_db.RegisterMessage(ConceptManager.PutAttributeType)
_sym_db.RegisterMessage(ConceptManager.PutAttributeType.Req)
_sym_db.RegisterMessage(ConceptManager.PutAttributeType.Res)
_sym_db.RegisterMessage(ConceptManager.PutRelationType)
_sym_db.RegisterMessage(ConceptManager.PutRelationType.Req)
_sym_db.RegisterMessage(ConceptManager.PutRelationType.Res)

Concept = _reflection.GeneratedProtocolMessageType('Concept', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPT,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Concept)
  ))
_sym_db.RegisterMessage(Concept)

Thing = _reflection.GeneratedProtocolMessageType('Thing', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _THING_REQ,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _THING_RES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.Res)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_DELETE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_DELETE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.Delete.Res)
      ))
    ,
    DESCRIPTOR = _THING_DELETE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.Delete)
    ))
  ,

  IsInferred = _reflection.GeneratedProtocolMessageType('IsInferred', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_ISINFERRED_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.IsInferred.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_ISINFERRED_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.IsInferred.Res)
      ))
    ,
    DESCRIPTOR = _THING_ISINFERRED,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.IsInferred)
    ))
  ,

  GetType = _reflection.GeneratedProtocolMessageType('GetType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetType.Res)
      ))
    ,
    DESCRIPTOR = _THING_GETTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetType)
    ))
  ,

  SetHas = _reflection.GeneratedProtocolMessageType('SetHas', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_SETHAS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.SetHas.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_SETHAS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.SetHas.Res)
      ))
    ,
    DESCRIPTOR = _THING_SETHAS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.SetHas)
    ))
  ,

  UnsetHas = _reflection.GeneratedProtocolMessageType('UnsetHas', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_UNSETHAS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.UnsetHas.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_UNSETHAS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.UnsetHas.Res)
      ))
    ,
    DESCRIPTOR = _THING_UNSETHAS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.UnsetHas)
    ))
  ,

  GetHas = _reflection.GeneratedProtocolMessageType('GetHas', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETHAS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetHas.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETHAS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetHas.Res)
      ))
    ,
    DESCRIPTOR = _THING_GETHAS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetHas)
    ))
  ,

  GetPlays = _reflection.GeneratedProtocolMessageType('GetPlays', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETPLAYS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetPlays.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETPLAYS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetPlays.Res)
      ))
    ,
    DESCRIPTOR = _THING_GETPLAYS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetPlays)
    ))
  ,

  GetRelations = _reflection.GeneratedProtocolMessageType('GetRelations', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETRELATIONS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetRelations.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THING_GETRELATIONS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetRelations.Res)
      ))
    ,
    DESCRIPTOR = _THING_GETRELATIONS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Thing.GetRelations)
    ))
  ,
  DESCRIPTOR = _THING,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Thing)
  ))
_sym_db.RegisterMessage(Thing)
_sym_db.RegisterMessage(Thing.Req)
_sym_db.RegisterMessage(Thing.Res)
_sym_db.RegisterMessage(Thing.Delete)
_sym_db.RegisterMessage(Thing.Delete.Req)
_sym_db.RegisterMessage(Thing.Delete.Res)
_sym_db.RegisterMessage(Thing.IsInferred)
_sym_db.RegisterMessage(Thing.IsInferred.Req)
_sym_db.RegisterMessage(Thing.IsInferred.Res)
_sym_db.RegisterMessage(Thing.GetType)
_sym_db.RegisterMessage(Thing.GetType.Req)
_sym_db.RegisterMessage(Thing.GetType.Res)
_sym_db.RegisterMessage(Thing.SetHas)
_sym_db.RegisterMessage(Thing.SetHas.Req)
_sym_db.RegisterMessage(Thing.SetHas.Res)
_sym_db.RegisterMessage(Thing.UnsetHas)
_sym_db.RegisterMessage(Thing.UnsetHas.Req)
_sym_db.RegisterMessage(Thing.UnsetHas.Res)
_sym_db.RegisterMessage(Thing.GetHas)
_sym_db.RegisterMessage(Thing.GetHas.Req)
_sym_db.RegisterMessage(Thing.GetHas.Res)
_sym_db.RegisterMessage(Thing.GetPlays)
_sym_db.RegisterMessage(Thing.GetPlays.Req)
_sym_db.RegisterMessage(Thing.GetPlays.Res)
_sym_db.RegisterMessage(Thing.GetRelations)
_sym_db.RegisterMessage(Thing.GetRelations.Req)
_sym_db.RegisterMessage(Thing.GetRelations.Res)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), dict(

  GetPlayers = _reflection.GeneratedProtocolMessageType('GetPlayers', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_GETPLAYERS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayers.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_GETPLAYERS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayers.Res)
      ))
    ,
    DESCRIPTOR = _RELATION_GETPLAYERS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayers)
    ))
  ,

  GetPlayersByRoleType = _reflection.GeneratedProtocolMessageType('GetPlayersByRoleType', (_message.Message,), dict(

    RoleTypeWithPlayer = _reflection.GeneratedProtocolMessageType('RoleTypeWithPlayer', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_GETPLAYERSBYROLETYPE_ROLETYPEWITHPLAYER,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayersByRoleType.RoleTypeWithPlayer)
      ))
    ,

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_GETPLAYERSBYROLETYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayersByRoleType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_GETPLAYERSBYROLETYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayersByRoleType.Res)
      ))
    ,
    DESCRIPTOR = _RELATION_GETPLAYERSBYROLETYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.GetPlayersByRoleType)
    ))
  ,

  AddPlayer = _reflection.GeneratedProtocolMessageType('AddPlayer', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_ADDPLAYER_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.AddPlayer.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_ADDPLAYER_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.AddPlayer.Res)
      ))
    ,
    DESCRIPTOR = _RELATION_ADDPLAYER,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.AddPlayer)
    ))
  ,

  RemovePlayer = _reflection.GeneratedProtocolMessageType('RemovePlayer', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_REMOVEPLAYER_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.RemovePlayer.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATION_REMOVEPLAYER_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.RemovePlayer.Res)
      ))
    ,
    DESCRIPTOR = _RELATION_REMOVEPLAYER,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Relation.RemovePlayer)
    ))
  ,
  DESCRIPTOR = _RELATION,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Relation)
  ))
_sym_db.RegisterMessage(Relation)
_sym_db.RegisterMessage(Relation.GetPlayers)
_sym_db.RegisterMessage(Relation.GetPlayers.Req)
_sym_db.RegisterMessage(Relation.GetPlayers.Res)
_sym_db.RegisterMessage(Relation.GetPlayersByRoleType)
_sym_db.RegisterMessage(Relation.GetPlayersByRoleType.RoleTypeWithPlayer)
_sym_db.RegisterMessage(Relation.GetPlayersByRoleType.Req)
_sym_db.RegisterMessage(Relation.GetPlayersByRoleType.Res)
_sym_db.RegisterMessage(Relation.AddPlayer)
_sym_db.RegisterMessage(Relation.AddPlayer.Req)
_sym_db.RegisterMessage(Relation.AddPlayer.Res)
_sym_db.RegisterMessage(Relation.RemovePlayer)
_sym_db.RegisterMessage(Relation.RemovePlayer.Req)
_sym_db.RegisterMessage(Relation.RemovePlayer.Res)

Attribute = _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), dict(

  GetOwners = _reflection.GeneratedProtocolMessageType('GetOwners', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTE_GETOWNERS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Attribute.GetOwners.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTE_GETOWNERS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Attribute.GetOwners.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTE_GETOWNERS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Attribute.GetOwners)
    ))
  ,

  Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
    DESCRIPTOR = _ATTRIBUTE_VALUE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Attribute.Value)
    ))
  ,
  DESCRIPTOR = _ATTRIBUTE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Attribute)
  ))
_sym_db.RegisterMessage(Attribute)
_sym_db.RegisterMessage(Attribute.GetOwners)
_sym_db.RegisterMessage(Attribute.GetOwners.Req)
_sym_db.RegisterMessage(Attribute.GetOwners.Res)
_sym_db.RegisterMessage(Attribute.Value)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_REQ,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_RES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.Res)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_DELETE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_DELETE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.Delete.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_DELETE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.Delete)
    ))
  ,

  SetLabel = _reflection.GeneratedProtocolMessageType('SetLabel', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_SETLABEL_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetLabel.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_SETLABEL_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetLabel.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_SETLABEL,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetLabel)
    ))
  ,

  IsAbstract = _reflection.GeneratedProtocolMessageType('IsAbstract', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_ISABSTRACT_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.IsAbstract.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_ISABSTRACT_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.IsAbstract.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_ISABSTRACT,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.IsAbstract)
    ))
  ,

  GetSupertype = _reflection.GeneratedProtocolMessageType('GetSupertype', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUPERTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertype.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUPERTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertype.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_GETSUPERTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertype)
    ))
  ,

  SetSupertype = _reflection.GeneratedProtocolMessageType('SetSupertype', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_SETSUPERTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetSupertype.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_SETSUPERTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetSupertype.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_SETSUPERTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.SetSupertype)
    ))
  ,

  GetSupertypes = _reflection.GeneratedProtocolMessageType('GetSupertypes', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUPERTYPES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertypes.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUPERTYPES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertypes.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_GETSUPERTYPES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSupertypes)
    ))
  ,

  GetSubtypes = _reflection.GeneratedProtocolMessageType('GetSubtypes', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUBTYPES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSubtypes.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TYPE_GETSUBTYPES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSubtypes.Res)
      ))
    ,
    DESCRIPTOR = _TYPE_GETSUBTYPES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Type.GetSubtypes)
    ))
  ,
  DESCRIPTOR = _TYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Type)
  ))
_sym_db.RegisterMessage(Type)
_sym_db.RegisterMessage(Type.Req)
_sym_db.RegisterMessage(Type.Res)
_sym_db.RegisterMessage(Type.Delete)
_sym_db.RegisterMessage(Type.Delete.Req)
_sym_db.RegisterMessage(Type.Delete.Res)
_sym_db.RegisterMessage(Type.SetLabel)
_sym_db.RegisterMessage(Type.SetLabel.Req)
_sym_db.RegisterMessage(Type.SetLabel.Res)
_sym_db.RegisterMessage(Type.IsAbstract)
_sym_db.RegisterMessage(Type.IsAbstract.Req)
_sym_db.RegisterMessage(Type.IsAbstract.Res)
_sym_db.RegisterMessage(Type.GetSupertype)
_sym_db.RegisterMessage(Type.GetSupertype.Req)
_sym_db.RegisterMessage(Type.GetSupertype.Res)
_sym_db.RegisterMessage(Type.SetSupertype)
_sym_db.RegisterMessage(Type.SetSupertype.Req)
_sym_db.RegisterMessage(Type.SetSupertype.Res)
_sym_db.RegisterMessage(Type.GetSupertypes)
_sym_db.RegisterMessage(Type.GetSupertypes.Req)
_sym_db.RegisterMessage(Type.GetSupertypes.Res)
_sym_db.RegisterMessage(Type.GetSubtypes)
_sym_db.RegisterMessage(Type.GetSubtypes.Req)
_sym_db.RegisterMessage(Type.GetSubtypes.Res)

RoleType = _reflection.GeneratedProtocolMessageType('RoleType', (_message.Message,), dict(

  GetRelationType = _reflection.GeneratedProtocolMessageType('GetRelationType', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETRELATIONTYPE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationType.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETRELATIONTYPE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationType.Res)
      ))
    ,
    DESCRIPTOR = _ROLETYPE_GETRELATIONTYPE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationType)
    ))
  ,

  GetRelationTypes = _reflection.GeneratedProtocolMessageType('GetRelationTypes', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETRELATIONTYPES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationTypes.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETRELATIONTYPES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationTypes.Res)
      ))
    ,
    DESCRIPTOR = _ROLETYPE_GETRELATIONTYPES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetRelationTypes)
    ))
  ,

  GetPlayers = _reflection.GeneratedProtocolMessageType('GetPlayers', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETPLAYERS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetPlayers.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ROLETYPE_GETPLAYERS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetPlayers.Res)
      ))
    ,
    DESCRIPTOR = _ROLETYPE_GETPLAYERS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType.GetPlayers)
    ))
  ,
  DESCRIPTOR = _ROLETYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.RoleType)
  ))
_sym_db.RegisterMessage(RoleType)
_sym_db.RegisterMessage(RoleType.GetRelationType)
_sym_db.RegisterMessage(RoleType.GetRelationType.Req)
_sym_db.RegisterMessage(RoleType.GetRelationType.Res)
_sym_db.RegisterMessage(RoleType.GetRelationTypes)
_sym_db.RegisterMessage(RoleType.GetRelationTypes.Req)
_sym_db.RegisterMessage(RoleType.GetRelationTypes.Res)
_sym_db.RegisterMessage(RoleType.GetPlayers)
_sym_db.RegisterMessage(RoleType.GetPlayers.Req)
_sym_db.RegisterMessage(RoleType.GetPlayers.Res)

ThingType = _reflection.GeneratedProtocolMessageType('ThingType', (_message.Message,), dict(

  SetAbstract = _reflection.GeneratedProtocolMessageType('SetAbstract', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETABSTRACT_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetAbstract.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETABSTRACT_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetAbstract.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_SETABSTRACT,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetAbstract)
    ))
  ,

  UnsetAbstract = _reflection.GeneratedProtocolMessageType('UnsetAbstract', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETABSTRACT_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetAbstract.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETABSTRACT_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetAbstract.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_UNSETABSTRACT,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetAbstract)
    ))
  ,

  GetInstances = _reflection.GeneratedProtocolMessageType('GetInstances', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETINSTANCES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetInstances.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETINSTANCES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetInstances.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_GETINSTANCES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetInstances)
    ))
  ,

  GetOwns = _reflection.GeneratedProtocolMessageType('GetOwns', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETOWNS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetOwns.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETOWNS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetOwns.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_GETOWNS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetOwns)
    ))
  ,

  GetPlays = _reflection.GeneratedProtocolMessageType('GetPlays', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETPLAYS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetPlays.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_GETPLAYS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetPlays.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_GETPLAYS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.GetPlays)
    ))
  ,

  SetOwns = _reflection.GeneratedProtocolMessageType('SetOwns', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETOWNS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetOwns.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETOWNS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetOwns.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_SETOWNS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetOwns)
    ))
  ,

  SetPlays = _reflection.GeneratedProtocolMessageType('SetPlays', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETPLAYS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetPlays.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_SETPLAYS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetPlays.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_SETPLAYS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.SetPlays)
    ))
  ,

  UnsetOwns = _reflection.GeneratedProtocolMessageType('UnsetOwns', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETOWNS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetOwns.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETOWNS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetOwns.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_UNSETOWNS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetOwns)
    ))
  ,

  UnsetPlays = _reflection.GeneratedProtocolMessageType('UnsetPlays', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETPLAYS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetPlays.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _THINGTYPE_UNSETPLAYS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetPlays.Res)
      ))
    ,
    DESCRIPTOR = _THINGTYPE_UNSETPLAYS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType.UnsetPlays)
    ))
  ,
  DESCRIPTOR = _THINGTYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.ThingType)
  ))
_sym_db.RegisterMessage(ThingType)
_sym_db.RegisterMessage(ThingType.SetAbstract)
_sym_db.RegisterMessage(ThingType.SetAbstract.Req)
_sym_db.RegisterMessage(ThingType.SetAbstract.Res)
_sym_db.RegisterMessage(ThingType.UnsetAbstract)
_sym_db.RegisterMessage(ThingType.UnsetAbstract.Req)
_sym_db.RegisterMessage(ThingType.UnsetAbstract.Res)
_sym_db.RegisterMessage(ThingType.GetInstances)
_sym_db.RegisterMessage(ThingType.GetInstances.Req)
_sym_db.RegisterMessage(ThingType.GetInstances.Res)
_sym_db.RegisterMessage(ThingType.GetOwns)
_sym_db.RegisterMessage(ThingType.GetOwns.Req)
_sym_db.RegisterMessage(ThingType.GetOwns.Res)
_sym_db.RegisterMessage(ThingType.GetPlays)
_sym_db.RegisterMessage(ThingType.GetPlays.Req)
_sym_db.RegisterMessage(ThingType.GetPlays.Res)
_sym_db.RegisterMessage(ThingType.SetOwns)
_sym_db.RegisterMessage(ThingType.SetOwns.Req)
_sym_db.RegisterMessage(ThingType.SetOwns.Res)
_sym_db.RegisterMessage(ThingType.SetPlays)
_sym_db.RegisterMessage(ThingType.SetPlays.Req)
_sym_db.RegisterMessage(ThingType.SetPlays.Res)
_sym_db.RegisterMessage(ThingType.UnsetOwns)
_sym_db.RegisterMessage(ThingType.UnsetOwns.Req)
_sym_db.RegisterMessage(ThingType.UnsetOwns.Res)
_sym_db.RegisterMessage(ThingType.UnsetPlays)
_sym_db.RegisterMessage(ThingType.UnsetPlays.Req)
_sym_db.RegisterMessage(ThingType.UnsetPlays.Res)

EntityType = _reflection.GeneratedProtocolMessageType('EntityType', (_message.Message,), dict(

  Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ENTITYTYPE_CREATE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.EntityType.Create.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ENTITYTYPE_CREATE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.EntityType.Create.Res)
      ))
    ,
    DESCRIPTOR = _ENTITYTYPE_CREATE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.EntityType.Create)
    ))
  ,
  DESCRIPTOR = _ENTITYTYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.EntityType)
  ))
_sym_db.RegisterMessage(EntityType)
_sym_db.RegisterMessage(EntityType.Create)
_sym_db.RegisterMessage(EntityType.Create.Req)
_sym_db.RegisterMessage(EntityType.Create.Res)

RelationType = _reflection.GeneratedProtocolMessageType('RelationType', (_message.Message,), dict(

  Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_CREATE_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.Create.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_CREATE_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.Create.Res)
      ))
    ,
    DESCRIPTOR = _RELATIONTYPE_CREATE,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.Create)
    ))
  ,

  GetRelates = _reflection.GeneratedProtocolMessageType('GetRelates', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_GETRELATES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelates.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_GETRELATES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelates.Res)
      ))
    ,
    DESCRIPTOR = _RELATIONTYPE_GETRELATES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelates)
    ))
  ,

  GetRelatesForRoleLabel = _reflection.GeneratedProtocolMessageType('GetRelatesForRoleLabel', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_GETRELATESFORROLELABEL_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelatesForRoleLabel.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_GETRELATESFORROLELABEL_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelatesForRoleLabel.Res)
      ))
    ,
    DESCRIPTOR = _RELATIONTYPE_GETRELATESFORROLELABEL,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.GetRelatesForRoleLabel)
    ))
  ,

  SetRelates = _reflection.GeneratedProtocolMessageType('SetRelates', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_SETRELATES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.SetRelates.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_SETRELATES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.SetRelates.Res)
      ))
    ,
    DESCRIPTOR = _RELATIONTYPE_SETRELATES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.SetRelates)
    ))
  ,

  UnsetRelates = _reflection.GeneratedProtocolMessageType('UnsetRelates', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_UNSETRELATES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.UnsetRelates.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RELATIONTYPE_UNSETRELATES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.UnsetRelates.Res)
      ))
    ,
    DESCRIPTOR = _RELATIONTYPE_UNSETRELATES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType.UnsetRelates)
    ))
  ,
  DESCRIPTOR = _RELATIONTYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.RelationType)
  ))
_sym_db.RegisterMessage(RelationType)
_sym_db.RegisterMessage(RelationType.Create)
_sym_db.RegisterMessage(RelationType.Create.Req)
_sym_db.RegisterMessage(RelationType.Create.Res)
_sym_db.RegisterMessage(RelationType.GetRelates)
_sym_db.RegisterMessage(RelationType.GetRelates.Req)
_sym_db.RegisterMessage(RelationType.GetRelates.Res)
_sym_db.RegisterMessage(RelationType.GetRelatesForRoleLabel)
_sym_db.RegisterMessage(RelationType.GetRelatesForRoleLabel.Req)
_sym_db.RegisterMessage(RelationType.GetRelatesForRoleLabel.Res)
_sym_db.RegisterMessage(RelationType.SetRelates)
_sym_db.RegisterMessage(RelationType.SetRelates.Req)
_sym_db.RegisterMessage(RelationType.SetRelates.Res)
_sym_db.RegisterMessage(RelationType.UnsetRelates)
_sym_db.RegisterMessage(RelationType.UnsetRelates.Req)
_sym_db.RegisterMessage(RelationType.UnsetRelates.Res)

AttributeType = _reflection.GeneratedProtocolMessageType('AttributeType', (_message.Message,), dict(

  Put = _reflection.GeneratedProtocolMessageType('Put', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_PUT_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Put.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_PUT_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Put.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_PUT,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Put)
    ))
  ,

  Get = _reflection.GeneratedProtocolMessageType('Get', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GET_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Get.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GET_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Get.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_GET,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.Get)
    ))
  ,

  GetOwners = _reflection.GeneratedProtocolMessageType('GetOwners', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETOWNERS_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetOwners.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETOWNERS_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetOwners.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_GETOWNERS,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetOwners)
    ))
  ,

  GetRegex = _reflection.GeneratedProtocolMessageType('GetRegex', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETREGEX_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetRegex.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETREGEX_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetRegex.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_GETREGEX,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetRegex)
    ))
  ,

  SetRegex = _reflection.GeneratedProtocolMessageType('SetRegex', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_SETREGEX_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.SetRegex.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_SETREGEX_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.SetRegex.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_SETREGEX,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.SetRegex)
    ))
  ,

  GetSubtypes = _reflection.GeneratedProtocolMessageType('GetSubtypes', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETSUBTYPES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetSubtypes.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETSUBTYPES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetSubtypes.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_GETSUBTYPES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetSubtypes)
    ))
  ,

  GetInstances = _reflection.GeneratedProtocolMessageType('GetInstances', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETINSTANCES_REQ,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetInstances.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _ATTRIBUTETYPE_GETINSTANCES_RES,
      __module__ = 'protobuf.concept_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetInstances.Res)
      ))
    ,
    DESCRIPTOR = _ATTRIBUTETYPE_GETINSTANCES,
    __module__ = 'protobuf.concept_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType.GetInstances)
    ))
  ,
  DESCRIPTOR = _ATTRIBUTETYPE,
  __module__ = 'protobuf.concept_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.AttributeType)
  ))
_sym_db.RegisterMessage(AttributeType)
_sym_db.RegisterMessage(AttributeType.Put)
_sym_db.RegisterMessage(AttributeType.Put.Req)
_sym_db.RegisterMessage(AttributeType.Put.Res)
_sym_db.RegisterMessage(AttributeType.Get)
_sym_db.RegisterMessage(AttributeType.Get.Req)
_sym_db.RegisterMessage(AttributeType.Get.Res)
_sym_db.RegisterMessage(AttributeType.GetOwners)
_sym_db.RegisterMessage(AttributeType.GetOwners.Req)
_sym_db.RegisterMessage(AttributeType.GetOwners.Res)
_sym_db.RegisterMessage(AttributeType.GetRegex)
_sym_db.RegisterMessage(AttributeType.GetRegex.Req)
_sym_db.RegisterMessage(AttributeType.GetRegex.Res)
_sym_db.RegisterMessage(AttributeType.SetRegex)
_sym_db.RegisterMessage(AttributeType.SetRegex.Req)
_sym_db.RegisterMessage(AttributeType.SetRegex.Res)
_sym_db.RegisterMessage(AttributeType.GetSubtypes)
_sym_db.RegisterMessage(AttributeType.GetSubtypes.Req)
_sym_db.RegisterMessage(AttributeType.GetSubtypes.Res)
_sym_db.RegisterMessage(AttributeType.GetInstances)
_sym_db.RegisterMessage(AttributeType.GetInstances.Req)
_sym_db.RegisterMessage(AttributeType.GetInstances.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
